# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: report.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import host_pb2 as host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0creport.proto\x12\x06report\x1a\nhost.proto\"U\n\nBootReport\x12 \n\x04host\x18\x01 \x01(\x0b\x32\x12.report.RenderHost\x12%\n\tcore_info\x18\x02 \x01(\x0b\x32\x12.report.CoreDetail\"\xea\x01\n\nCoreDetail\x12\x13\n\x0btotal_cores\x18\x01 \x01(\x05\x12\x12\n\nidle_cores\x18\x02 \x01(\x05\x12\x14\n\x0clocked_cores\x18\x03 \x01(\x05\x12\x14\n\x0c\x62ooked_cores\x18\x04 \x01(\x05\x12\x41\n\x0ereserved_cores\x18\x05 \x03(\x0b\x32%.report.CoreDetail.ReservedCoresEntryB\x02\x18\x01\x1a\x44\n\x12ReservedCoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.report.CoreId:\x02\x38\x01\"\x18\n\x06\x43oreId\x12\x0e\n\x06\x63oreid\x18\x01 \x03(\x03\"\x9c\x01\n\x13\x46rameCompleteReport\x12 \n\x04host\x18\x01 \x01(\x0b\x32\x12.report.RenderHost\x12\'\n\x05\x66rame\x18\x02 \x01(\x0b\x32\x18.report.RunningFrameInfo\x12\x13\n\x0b\x65xit_status\x18\x03 \x01(\x05\x12\x13\n\x0b\x65xit_signal\x18\x04 \x01(\x05\x12\x10\n\x08run_time\x18\x05 \x01(\x05\"\x7f\n\nHostReport\x12 \n\x04host\x18\x01 \x01(\x0b\x32\x12.report.RenderHost\x12(\n\x06\x66rames\x18\x02 \x03(\x0b\x32\x18.report.RunningFrameInfo\x12%\n\tcore_info\x18\x03 \x01(\x0b\x32\x12.report.CoreDetail\"\xf2\x03\n\nRenderHost\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rnimby_enabled\x18\x02 \x01(\x08\x12\x14\n\x0cnimby_locked\x18\x03 \x01(\x08\x12\x10\n\x08\x66\x61\x63ility\x18\x04 \x01(\t\x12\x11\n\tnum_procs\x18\x05 \x01(\x05\x12\x16\n\x0e\x63ores_per_proc\x18\x06 \x01(\x05\x12\x12\n\ntotal_swap\x18\x07 \x01(\x03\x12\x11\n\ttotal_mem\x18\x08 \x01(\x03\x12\x11\n\ttotal_mcp\x18\t \x01(\x03\x12\x11\n\tfree_swap\x18\n \x01(\x03\x12\x10\n\x08\x66ree_mem\x18\x0b \x01(\x03\x12\x10\n\x08\x66ree_mcp\x18\x0c \x01(\x03\x12\x0c\n\x04load\x18\r \x01(\x05\x12\x11\n\tboot_time\x18\x0e \x01(\x05\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\"\n\x05state\x18\x10 \x01(\x0e\x32\x13.host.HardwareState\x12\x36\n\nattributes\x18\x11 \x03(\x0b\x32\".report.RenderHost.AttributesEntry\x12\x10\n\x08num_gpus\x18\x12 \x01(\x05\x12\x14\n\x0c\x66ree_gpu_mem\x18\x13 \x01(\x03\x12\x15\n\rtotal_gpu_mem\x18\x14 \x01(\x03\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x03\n\x10RunningFrameInfo\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x10\n\x08job_name\x18\x03 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x10\n\x08layer_id\x18\x06 \x01(\t\x12\x11\n\tnum_cores\x18\x07 \x01(\x05\x12\x12\n\nstart_time\x18\x08 \x01(\x03\x12\x0f\n\x07max_rss\x18\t \x01(\x03\x12\x0b\n\x03rss\x18\n \x01(\x03\x12\x11\n\tmax_vsize\x18\x0b \x01(\x03\x12\r\n\x05vsize\x18\x0c \x01(\x03\x12<\n\nattributes\x18\r \x03(\x0b\x32(.report.RunningFrameInfo.AttributesEntry\x12\x10\n\x08llu_time\x18\x0e \x01(\x03\x12\x10\n\x08num_gpus\x18\x0f \x01(\x05\x12\x1b\n\x13max_used_gpu_memory\x18\x10 \x01(\x03\x12\x17\n\x0fused_gpu_memory\x18\x11 \x01(\x03\x12+\n\x08\x63hildren\x18\x12 \x01(\x0b\x32\x19.report.ChildrenProcStats\x12\x18\n\x10used_swap_memory\x18\x13 \x01(\x03\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x11\x43hildrenProcStats\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.report.ProcStats\"\x8a\x01\n\tProcStats\x12\x1a\n\x04stat\x18\x01 \x01(\x0b\x32\x0c.report.Stat\x12\x1c\n\x05statm\x18\x02 \x01(\x0b\x32\r.report.Statm\x12\x1e\n\x06status\x18\x03 \x01(\x0b\x32\x0e.report.Status\x12\x0f\n\x07\x63mdline\x18\x04 \x01(\t\x12\x12\n\nstart_time\x18\x05 \x01(\t\"L\n\x04Stat\x12\x0b\n\x03rss\x18\x01 \x01(\x03\x12\r\n\x05vsize\x18\x02 \x01(\x03\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0b\n\x03pid\x18\x05 \x01(\t\"\"\n\x05Statm\x12\x0b\n\x03rss\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\"%\n\x06Status\x12\x0c\n\x04vrss\x18\x01 \x01(\x03\x12\r\n\x05vsize\x18\x02 \x01(\x03\"Q\n\x18\x43hildrenProcStatsRequest\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.report.ProcStats\"T\n\x19\x43hildrenProcStatsResponse\x12\x37\n\x14\x63hildren_procs_stats\x18\x01 \x01(\x0b\x32\x19.report.ChildrenProcStats\"o\n\x10ProcStatsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04stat\x18\x02 \x01(\t\x12\r\n\x05statm\x18\x03 \x01(\t\x12\x0f\n\x07\x63mdline\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x06 \x01(\t\":\n\x11ProcStatsResponse\x12%\n\nproc_stats\x18\x01 \x01(\x0b\x32\x11.report.ProcStats\"E\n\x1aRqdReportRqdStartupRequest\x12\'\n\x0b\x62oot_report\x18\x01 \x01(\x0b\x32\x12.report.BootReport\"\x1d\n\x1bRqdReportRqdStartupResponse\"d\n&RqdReportRunningFrameCompletionRequest\x12:\n\x15\x66rame_complete_report\x18\x01 \x01(\x0b\x32\x1b.report.FrameCompleteReport\")\n\'RqdReportRunningFrameCompletionResponse\"A\n\x16RqdReportStatusRequest\x12\'\n\x0bhost_report\x18\x01 \x01(\x0b\x32\x12.report.HostReport\"\x19\n\x17RqdReportStatusResponse2\xc3\x02\n\x12RqdReportInterface\x12[\n\x10ReportRqdStartup\x12\".report.RqdReportRqdStartupRequest\x1a#.report.RqdReportRqdStartupResponse\x12\x7f\n\x1cReportRunningFrameCompletion\x12..report.RqdReportRunningFrameCompletionRequest\x1a/.report.RqdReportRunningFrameCompletionResponse\x12O\n\x0cReportStatus\x12\x1e.report.RqdReportStatusRequest\x1a\x1f.report.RqdReportStatusResponseB<\n com.imageworks.spcue.grpc.reportP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.imageworks.spcue.grpc.reportP\001Z\026opencue_gateway/gen/go'
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._options = None
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._serialized_options = b'8\001'
  _globals['_COREDETAIL'].fields_by_name['reserved_cores']._options = None
  _globals['_COREDETAIL'].fields_by_name['reserved_cores']._serialized_options = b'\030\001'
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._options = None
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._options = None
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_BOOTREPORT']._serialized_start=36
  _globals['_BOOTREPORT']._serialized_end=121
  _globals['_COREDETAIL']._serialized_start=124
  _globals['_COREDETAIL']._serialized_end=358
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._serialized_start=290
  _globals['_COREDETAIL_RESERVEDCORESENTRY']._serialized_end=358
  _globals['_COREID']._serialized_start=360
  _globals['_COREID']._serialized_end=384
  _globals['_FRAMECOMPLETEREPORT']._serialized_start=387
  _globals['_FRAMECOMPLETEREPORT']._serialized_end=543
  _globals['_HOSTREPORT']._serialized_start=545
  _globals['_HOSTREPORT']._serialized_end=672
  _globals['_RENDERHOST']._serialized_start=675
  _globals['_RENDERHOST']._serialized_end=1173
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._serialized_start=1124
  _globals['_RENDERHOST_ATTRIBUTESENTRY']._serialized_end=1173
  _globals['_RUNNINGFRAMEINFO']._serialized_start=1176
  _globals['_RUNNINGFRAMEINFO']._serialized_end=1682
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._serialized_start=1124
  _globals['_RUNNINGFRAMEINFO_ATTRIBUTESENTRY']._serialized_end=1173
  _globals['_CHILDRENPROCSTATS']._serialized_start=1684
  _globals['_CHILDRENPROCSTATS']._serialized_end=1740
  _globals['_PROCSTATS']._serialized_start=1743
  _globals['_PROCSTATS']._serialized_end=1881
  _globals['_STAT']._serialized_start=1883
  _globals['_STAT']._serialized_end=1959
  _globals['_STATM']._serialized_start=1961
  _globals['_STATM']._serialized_end=1995
  _globals['_STATUS']._serialized_start=1997
  _globals['_STATUS']._serialized_end=2034
  _globals['_CHILDRENPROCSTATSREQUEST']._serialized_start=2036
  _globals['_CHILDRENPROCSTATSREQUEST']._serialized_end=2117
  _globals['_CHILDRENPROCSTATSRESPONSE']._serialized_start=2119
  _globals['_CHILDRENPROCSTATSRESPONSE']._serialized_end=2203
  _globals['_PROCSTATSREQUEST']._serialized_start=2205
  _globals['_PROCSTATSREQUEST']._serialized_end=2316
  _globals['_PROCSTATSRESPONSE']._serialized_start=2318
  _globals['_PROCSTATSRESPONSE']._serialized_end=2376
  _globals['_RQDREPORTRQDSTARTUPREQUEST']._serialized_start=2378
  _globals['_RQDREPORTRQDSTARTUPREQUEST']._serialized_end=2447
  _globals['_RQDREPORTRQDSTARTUPRESPONSE']._serialized_start=2449
  _globals['_RQDREPORTRQDSTARTUPRESPONSE']._serialized_end=2478
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONREQUEST']._serialized_start=2480
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONREQUEST']._serialized_end=2580
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONRESPONSE']._serialized_start=2582
  _globals['_RQDREPORTRUNNINGFRAMECOMPLETIONRESPONSE']._serialized_end=2623
  _globals['_RQDREPORTSTATUSREQUEST']._serialized_start=2625
  _globals['_RQDREPORTSTATUSREQUEST']._serialized_end=2690
  _globals['_RQDREPORTSTATUSRESPONSE']._serialized_start=2692
  _globals['_RQDREPORTSTATUSRESPONSE']._serialized_end=2717
  _globals['_RQDREPORTINTERFACE']._serialized_start=2720
  _globals['_RQDREPORTINTERFACE']._serialized_end=3043
# @@protoc_insertion_point(module_scope)