# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import show_pb2 as show__pb2


class ShowInterfaceStub(object):
    """Shows are the top level object for work.

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateFilter = channel.unary_unary(
                '/show.ShowInterface/CreateFilter',
                request_serializer=show__pb2.ShowCreateFilterRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateFilterResponse.FromString,
                )
        self.CreateOwner = channel.unary_unary(
                '/show.ShowInterface/CreateOwner',
                request_serializer=show__pb2.ShowCreateOwnerRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateOwnerResponse.FromString,
                )
        self.CreateServiceOverride = channel.unary_unary(
                '/show.ShowInterface/CreateServiceOverride',
                request_serializer=show__pb2.ShowCreateServiceOverrideRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateServiceOverrideResponse.FromString,
                )
        self.CreateShow = channel.unary_unary(
                '/show.ShowInterface/CreateShow',
                request_serializer=show__pb2.ShowCreateShowRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateShowResponse.FromString,
                )
        self.CreateSubscription = channel.unary_unary(
                '/show.ShowInterface/CreateSubscription',
                request_serializer=show__pb2.ShowCreateSubscriptionRequest.SerializeToString,
                response_deserializer=show__pb2.ShowCreateSubscriptionResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/show.ShowInterface/Delete',
                request_serializer=show__pb2.ShowDeleteRequest.SerializeToString,
                response_deserializer=show__pb2.ShowDeleteResponse.FromString,
                )
        self.EnableBooking = channel.unary_unary(
                '/show.ShowInterface/EnableBooking',
                request_serializer=show__pb2.ShowEnableBookingRequest.SerializeToString,
                response_deserializer=show__pb2.ShowEnableBookingResponse.FromString,
                )
        self.EnableDispatching = channel.unary_unary(
                '/show.ShowInterface/EnableDispatching',
                request_serializer=show__pb2.ShowEnableDispatchingRequest.SerializeToString,
                response_deserializer=show__pb2.ShowEnableDispatchingResponse.FromString,
                )
        self.FindFilter = channel.unary_unary(
                '/show.ShowInterface/FindFilter',
                request_serializer=show__pb2.ShowFindFilterRequest.SerializeToString,
                response_deserializer=show__pb2.ShowFindFilterResponse.FromString,
                )
        self.FindShow = channel.unary_unary(
                '/show.ShowInterface/FindShow',
                request_serializer=show__pb2.ShowFindShowRequest.SerializeToString,
                response_deserializer=show__pb2.ShowFindShowResponse.FromString,
                )
        self.GetActiveShows = channel.unary_unary(
                '/show.ShowInterface/GetActiveShows',
                request_serializer=show__pb2.ShowGetActiveShowsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetActiveShowsResponse.FromString,
                )
        self.GetDeeds = channel.unary_unary(
                '/show.ShowInterface/GetDeeds',
                request_serializer=show__pb2.ShowGetDeedsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetDeedsResponse.FromString,
                )
        self.GetDepartment = channel.unary_unary(
                '/show.ShowInterface/GetDepartment',
                request_serializer=show__pb2.ShowGetDepartmentRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetDepartmentResponse.FromString,
                )
        self.GetDepartments = channel.unary_unary(
                '/show.ShowInterface/GetDepartments',
                request_serializer=show__pb2.ShowGetDepartmentsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetDepartmentsResponse.FromString,
                )
        self.GetFilters = channel.unary_unary(
                '/show.ShowInterface/GetFilters',
                request_serializer=show__pb2.ShowGetFiltersRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetFiltersResponse.FromString,
                )
        self.GetGroups = channel.unary_unary(
                '/show.ShowInterface/GetGroups',
                request_serializer=show__pb2.ShowGetGroupsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetGroupsResponse.FromString,
                )
        self.GetJobs = channel.unary_unary(
                '/show.ShowInterface/GetJobs',
                request_serializer=show__pb2.ShowGetJobsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetJobsResponse.FromString,
                )
        self.GetJobWhiteboard = channel.unary_unary(
                '/show.ShowInterface/GetJobWhiteboard',
                request_serializer=show__pb2.ShowGetJobWhiteboardRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetJobWhiteboardResponse.FromString,
                )
        self.GetRootGroup = channel.unary_unary(
                '/show.ShowInterface/GetRootGroup',
                request_serializer=show__pb2.ShowGetRootGroupRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetRootGroupResponse.FromString,
                )
        self.GetServiceOverride = channel.unary_unary(
                '/show.ShowInterface/GetServiceOverride',
                request_serializer=show__pb2.ShowGetServiceOverrideRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetServiceOverrideResponse.FromString,
                )
        self.GetServiceOverrides = channel.unary_unary(
                '/show.ShowInterface/GetServiceOverrides',
                request_serializer=show__pb2.ShowGetServiceOverridesRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetServiceOverridesResponse.FromString,
                )
        self.GetShows = channel.unary_unary(
                '/show.ShowInterface/GetShows',
                request_serializer=show__pb2.ShowGetShowsRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetShowsResponse.FromString,
                )
        self.GetSubscriptions = channel.unary_unary(
                '/show.ShowInterface/GetSubscriptions',
                request_serializer=show__pb2.ShowGetSubscriptionRequest.SerializeToString,
                response_deserializer=show__pb2.ShowGetSubscriptionResponse.FromString,
                )
        self.SetActive = channel.unary_unary(
                '/show.ShowInterface/SetActive',
                request_serializer=show__pb2.ShowSetActiveRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetActiveResponse.FromString,
                )
        self.SetCommentEmail = channel.unary_unary(
                '/show.ShowInterface/SetCommentEmail',
                request_serializer=show__pb2.ShowSetCommentEmailRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetCommentEmailResponse.FromString,
                )
        self.SetDefaultMaxCores = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMaxCores',
                request_serializer=show__pb2.ShowSetDefaultMaxCoresRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMaxCoresResponse.FromString,
                )
        self.SetDefaultMinCores = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMinCores',
                request_serializer=show__pb2.ShowSetDefaultMinCoresRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMinCoresResponse.FromString,
                )
        self.SetDefaultMaxGpus = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMaxGpus',
                request_serializer=show__pb2.ShowSetDefaultMaxGpusRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMaxGpusResponse.FromString,
                )
        self.SetDefaultMinGpus = channel.unary_unary(
                '/show.ShowInterface/SetDefaultMinGpus',
                request_serializer=show__pb2.ShowSetDefaultMinGpusRequest.SerializeToString,
                response_deserializer=show__pb2.ShowSetDefaultMinGpusResponse.FromString,
                )
        self.Archive = channel.unary_unary(
                '/show.ShowInterface/Archive',
                request_serializer=show__pb2.ShowArchiveRequest.SerializeToString,
                response_deserializer=show__pb2.ShowArchiveResponse.FromString,
                )


class ShowInterfaceServicer(object):
    """Shows are the top level object for work.

    -------- Services --------]

    """

    def CreateFilter(self, request, context):
        """Creates a new empty filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOwner(self, request, context):
        """Create a new owner.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateServiceOverride(self, request, context):
        """Add a new service overrides.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShow(self, request, context):
        """Creates a show with the specified name and returns it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSubscription(self, request, context):
        """creates a new subscription
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a show if no jobs were ever launched for the show
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableBooking(self, request, context):
        """Enables/disables automated resource assignment. If this is disabled no new resources will be assigned but
        existing resources will continue to dispatch.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDispatching(self, request, context):
        """Enables/disables job dispatching.  If this is disabled then new resources are assigned but existing resources
        are always unbooked after each completed frame.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindFilter(self, request, context):
        """finds a filter by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindShow(self, request, context):
        """Find a show with the specified name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveShows(self, request, context):
        """Returns a list of all active shows.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeeds(self, request, context):
        """Return all the host deeds for the specified show.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDepartment(self, request, context):
        """Returns the department manager for the specified department
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDepartments(self, request, context):
        """Returns a list of all active departments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFilters(self, request, context):
        """Grabs a list of show filters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroups(self, request, context):
        """returns a list of job groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobs(self, request, context):
        """returns a flat list of jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobWhiteboard(self, request, context):
        """returns the show's job whiteboard
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRootGroup(self, request, context):
        """returns the root group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceOverride(self, request, context):
        """Get a service override based on its name or id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceOverrides(self, request, context):
        """Get a list of service overrides for this show.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetShows(self, request, context):
        """Returns a list of all shows
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubscriptions(self, request, context):
        """returns a list of a shows subscriptions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetActive(self, request, context):
        """Set a show's active to enabled/disabled. Active shows can be queried using the getActiveShows() method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCommentEmail(self, request, context):
        """If set, all comments on a show are echoed to the given list of email addresses.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMaxCores(self, request, context):
        """sets a show's default max procs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMinCores(self, request, context):
        """sets a show's default min procs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMaxGpus(self, request, context):
        """sets a show's default max Gpus
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultMinGpus(self, request, context):
        """sets a show's default min Gpus
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Archive(self, request, context):
        """Archives a show by creating an alias to another show and renaming the original show
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ShowInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFilter,
                    request_deserializer=show__pb2.ShowCreateFilterRequest.FromString,
                    response_serializer=show__pb2.ShowCreateFilterResponse.SerializeToString,
            ),
            'CreateOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOwner,
                    request_deserializer=show__pb2.ShowCreateOwnerRequest.FromString,
                    response_serializer=show__pb2.ShowCreateOwnerResponse.SerializeToString,
            ),
            'CreateServiceOverride': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateServiceOverride,
                    request_deserializer=show__pb2.ShowCreateServiceOverrideRequest.FromString,
                    response_serializer=show__pb2.ShowCreateServiceOverrideResponse.SerializeToString,
            ),
            'CreateShow': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShow,
                    request_deserializer=show__pb2.ShowCreateShowRequest.FromString,
                    response_serializer=show__pb2.ShowCreateShowResponse.SerializeToString,
            ),
            'CreateSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSubscription,
                    request_deserializer=show__pb2.ShowCreateSubscriptionRequest.FromString,
                    response_serializer=show__pb2.ShowCreateSubscriptionResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=show__pb2.ShowDeleteRequest.FromString,
                    response_serializer=show__pb2.ShowDeleteResponse.SerializeToString,
            ),
            'EnableBooking': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableBooking,
                    request_deserializer=show__pb2.ShowEnableBookingRequest.FromString,
                    response_serializer=show__pb2.ShowEnableBookingResponse.SerializeToString,
            ),
            'EnableDispatching': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDispatching,
                    request_deserializer=show__pb2.ShowEnableDispatchingRequest.FromString,
                    response_serializer=show__pb2.ShowEnableDispatchingResponse.SerializeToString,
            ),
            'FindFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.FindFilter,
                    request_deserializer=show__pb2.ShowFindFilterRequest.FromString,
                    response_serializer=show__pb2.ShowFindFilterResponse.SerializeToString,
            ),
            'FindShow': grpc.unary_unary_rpc_method_handler(
                    servicer.FindShow,
                    request_deserializer=show__pb2.ShowFindShowRequest.FromString,
                    response_serializer=show__pb2.ShowFindShowResponse.SerializeToString,
            ),
            'GetActiveShows': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveShows,
                    request_deserializer=show__pb2.ShowGetActiveShowsRequest.FromString,
                    response_serializer=show__pb2.ShowGetActiveShowsResponse.SerializeToString,
            ),
            'GetDeeds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeeds,
                    request_deserializer=show__pb2.ShowGetDeedsRequest.FromString,
                    response_serializer=show__pb2.ShowGetDeedsResponse.SerializeToString,
            ),
            'GetDepartment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDepartment,
                    request_deserializer=show__pb2.ShowGetDepartmentRequest.FromString,
                    response_serializer=show__pb2.ShowGetDepartmentResponse.SerializeToString,
            ),
            'GetDepartments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDepartments,
                    request_deserializer=show__pb2.ShowGetDepartmentsRequest.FromString,
                    response_serializer=show__pb2.ShowGetDepartmentsResponse.SerializeToString,
            ),
            'GetFilters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFilters,
                    request_deserializer=show__pb2.ShowGetFiltersRequest.FromString,
                    response_serializer=show__pb2.ShowGetFiltersResponse.SerializeToString,
            ),
            'GetGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroups,
                    request_deserializer=show__pb2.ShowGetGroupsRequest.FromString,
                    response_serializer=show__pb2.ShowGetGroupsResponse.SerializeToString,
            ),
            'GetJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobs,
                    request_deserializer=show__pb2.ShowGetJobsRequest.FromString,
                    response_serializer=show__pb2.ShowGetJobsResponse.SerializeToString,
            ),
            'GetJobWhiteboard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobWhiteboard,
                    request_deserializer=show__pb2.ShowGetJobWhiteboardRequest.FromString,
                    response_serializer=show__pb2.ShowGetJobWhiteboardResponse.SerializeToString,
            ),
            'GetRootGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRootGroup,
                    request_deserializer=show__pb2.ShowGetRootGroupRequest.FromString,
                    response_serializer=show__pb2.ShowGetRootGroupResponse.SerializeToString,
            ),
            'GetServiceOverride': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceOverride,
                    request_deserializer=show__pb2.ShowGetServiceOverrideRequest.FromString,
                    response_serializer=show__pb2.ShowGetServiceOverrideResponse.SerializeToString,
            ),
            'GetServiceOverrides': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceOverrides,
                    request_deserializer=show__pb2.ShowGetServiceOverridesRequest.FromString,
                    response_serializer=show__pb2.ShowGetServiceOverridesResponse.SerializeToString,
            ),
            'GetShows': grpc.unary_unary_rpc_method_handler(
                    servicer.GetShows,
                    request_deserializer=show__pb2.ShowGetShowsRequest.FromString,
                    response_serializer=show__pb2.ShowGetShowsResponse.SerializeToString,
            ),
            'GetSubscriptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubscriptions,
                    request_deserializer=show__pb2.ShowGetSubscriptionRequest.FromString,
                    response_serializer=show__pb2.ShowGetSubscriptionResponse.SerializeToString,
            ),
            'SetActive': grpc.unary_unary_rpc_method_handler(
                    servicer.SetActive,
                    request_deserializer=show__pb2.ShowSetActiveRequest.FromString,
                    response_serializer=show__pb2.ShowSetActiveResponse.SerializeToString,
            ),
            'SetCommentEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCommentEmail,
                    request_deserializer=show__pb2.ShowSetCommentEmailRequest.FromString,
                    response_serializer=show__pb2.ShowSetCommentEmailResponse.SerializeToString,
            ),
            'SetDefaultMaxCores': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMaxCores,
                    request_deserializer=show__pb2.ShowSetDefaultMaxCoresRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMaxCoresResponse.SerializeToString,
            ),
            'SetDefaultMinCores': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMinCores,
                    request_deserializer=show__pb2.ShowSetDefaultMinCoresRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMinCoresResponse.SerializeToString,
            ),
            'SetDefaultMaxGpus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMaxGpus,
                    request_deserializer=show__pb2.ShowSetDefaultMaxGpusRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMaxGpusResponse.SerializeToString,
            ),
            'SetDefaultMinGpus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultMinGpus,
                    request_deserializer=show__pb2.ShowSetDefaultMinGpusRequest.FromString,
                    response_serializer=show__pb2.ShowSetDefaultMinGpusResponse.SerializeToString,
            ),
            'Archive': grpc.unary_unary_rpc_method_handler(
                    servicer.Archive,
                    request_deserializer=show__pb2.ShowArchiveRequest.FromString,
                    response_serializer=show__pb2.ShowArchiveResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'show.ShowInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ShowInterface(object):
    """Shows are the top level object for work.

    -------- Services --------]

    """

    @staticmethod
    def CreateFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateFilter',
            show__pb2.ShowCreateFilterRequest.SerializeToString,
            show__pb2.ShowCreateFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateOwner',
            show__pb2.ShowCreateOwnerRequest.SerializeToString,
            show__pb2.ShowCreateOwnerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateServiceOverride(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateServiceOverride',
            show__pb2.ShowCreateServiceOverrideRequest.SerializeToString,
            show__pb2.ShowCreateServiceOverrideResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateShow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateShow',
            show__pb2.ShowCreateShowRequest.SerializeToString,
            show__pb2.ShowCreateShowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/CreateSubscription',
            show__pb2.ShowCreateSubscriptionRequest.SerializeToString,
            show__pb2.ShowCreateSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/Delete',
            show__pb2.ShowDeleteRequest.SerializeToString,
            show__pb2.ShowDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableBooking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/EnableBooking',
            show__pb2.ShowEnableBookingRequest.SerializeToString,
            show__pb2.ShowEnableBookingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDispatching(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/EnableDispatching',
            show__pb2.ShowEnableDispatchingRequest.SerializeToString,
            show__pb2.ShowEnableDispatchingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/FindFilter',
            show__pb2.ShowFindFilterRequest.SerializeToString,
            show__pb2.ShowFindFilterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindShow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/FindShow',
            show__pb2.ShowFindShowRequest.SerializeToString,
            show__pb2.ShowFindShowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveShows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetActiveShows',
            show__pb2.ShowGetActiveShowsRequest.SerializeToString,
            show__pb2.ShowGetActiveShowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeeds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetDeeds',
            show__pb2.ShowGetDeedsRequest.SerializeToString,
            show__pb2.ShowGetDeedsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDepartment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetDepartment',
            show__pb2.ShowGetDepartmentRequest.SerializeToString,
            show__pb2.ShowGetDepartmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDepartments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetDepartments',
            show__pb2.ShowGetDepartmentsRequest.SerializeToString,
            show__pb2.ShowGetDepartmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetFilters',
            show__pb2.ShowGetFiltersRequest.SerializeToString,
            show__pb2.ShowGetFiltersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetGroups',
            show__pb2.ShowGetGroupsRequest.SerializeToString,
            show__pb2.ShowGetGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetJobs',
            show__pb2.ShowGetJobsRequest.SerializeToString,
            show__pb2.ShowGetJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobWhiteboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetJobWhiteboard',
            show__pb2.ShowGetJobWhiteboardRequest.SerializeToString,
            show__pb2.ShowGetJobWhiteboardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRootGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetRootGroup',
            show__pb2.ShowGetRootGroupRequest.SerializeToString,
            show__pb2.ShowGetRootGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceOverride(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetServiceOverride',
            show__pb2.ShowGetServiceOverrideRequest.SerializeToString,
            show__pb2.ShowGetServiceOverrideResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceOverrides(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetServiceOverrides',
            show__pb2.ShowGetServiceOverridesRequest.SerializeToString,
            show__pb2.ShowGetServiceOverridesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetShows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetShows',
            show__pb2.ShowGetShowsRequest.SerializeToString,
            show__pb2.ShowGetShowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSubscriptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/GetSubscriptions',
            show__pb2.ShowGetSubscriptionRequest.SerializeToString,
            show__pb2.ShowGetSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetActive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetActive',
            show__pb2.ShowSetActiveRequest.SerializeToString,
            show__pb2.ShowSetActiveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCommentEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetCommentEmail',
            show__pb2.ShowSetCommentEmailRequest.SerializeToString,
            show__pb2.ShowSetCommentEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMaxCores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMaxCores',
            show__pb2.ShowSetDefaultMaxCoresRequest.SerializeToString,
            show__pb2.ShowSetDefaultMaxCoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMinCores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMinCores',
            show__pb2.ShowSetDefaultMinCoresRequest.SerializeToString,
            show__pb2.ShowSetDefaultMinCoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMaxGpus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMaxGpus',
            show__pb2.ShowSetDefaultMaxGpusRequest.SerializeToString,
            show__pb2.ShowSetDefaultMaxGpusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultMinGpus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/SetDefaultMinGpus',
            show__pb2.ShowSetDefaultMinGpusRequest.SerializeToString,
            show__pb2.ShowSetDefaultMinGpusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Archive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/show.ShowInterface/Archive',
            show__pb2.ShowArchiveRequest.SerializeToString,
            show__pb2.ShowArchiveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)