# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: comment.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcomment.proto\x12\x07\x63omment\"X\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x05\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"0\n\nCommentSeq\x12\"\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x10.comment.Comment\"9\n\x14\x43ommentDeleteRequest\x12!\n\x07\x63omment\x18\x01 \x01(\x0b\x32\x10.comment.Comment\"\x17\n\x15\x43ommentDeleteResponse\"7\n\x12\x43ommentSaveRequest\x12!\n\x07\x63omment\x18\x01 \x01(\x0b\x32\x10.comment.Comment\"\x15\n\x13\x43ommentSaveResponse2\x9e\x01\n\x10\x43ommentInterface\x12G\n\x06\x44\x65lete\x12\x1d.comment.CommentDeleteRequest\x1a\x1e.comment.CommentDeleteResponse\x12\x41\n\x04Save\x12\x1b.comment.CommentSaveRequest\x1a\x1c.comment.CommentSaveResponseB=\n!com.imageworks.spcue.grpc.commentP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'comment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.imageworks.spcue.grpc.commentP\001Z\026opencue_gateway/gen/go'
  _globals['_COMMENT']._serialized_start=26
  _globals['_COMMENT']._serialized_end=114
  _globals['_COMMENTSEQ']._serialized_start=116
  _globals['_COMMENTSEQ']._serialized_end=164
  _globals['_COMMENTDELETEREQUEST']._serialized_start=166
  _globals['_COMMENTDELETEREQUEST']._serialized_end=223
  _globals['_COMMENTDELETERESPONSE']._serialized_start=225
  _globals['_COMMENTDELETERESPONSE']._serialized_end=248
  _globals['_COMMENTSAVEREQUEST']._serialized_start=250
  _globals['_COMMENTSAVEREQUEST']._serialized_end=305
  _globals['_COMMENTSAVERESPONSE']._serialized_start=307
  _globals['_COMMENTSAVERESPONSE']._serialized_end=328
  _globals['_COMMENTINTERFACE']._serialized_start=331
  _globals['_COMMENTINTERFACE']._serialized_end=489
# @@protoc_insertion_point(module_scope)