# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: show.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import department_pb2 as department__pb2
from . import filter_pb2 as filter__pb2
from . import host_pb2 as host__pb2
from . import job_pb2 as job__pb2
from . import service_pb2 as service__pb2
from . import subscription_pb2 as subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nshow.proto\x12\x04show\x1a\x10\x64\x65partment.proto\x1a\x0c\x66ilter.proto\x1a\nhost.proto\x1a\tjob.proto\x1a\rservice.proto\x1a\x12subscription.proto\"\x89\x02\n\x04Show\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_min_cores\x18\x03 \x01(\x02\x12\x19\n\x11\x64\x65\x66\x61ult_max_cores\x18\x04 \x01(\x02\x12\x15\n\rcomment_email\x18\x05 \x01(\t\x12\x17\n\x0f\x62ooking_enabled\x18\x06 \x01(\x08\x12\x18\n\x10\x64ispatch_enabled\x18\x07 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x08 \x01(\x08\x12#\n\nshow_stats\x18\t \x01(\x0b\x32\x0f.show.ShowStats\x12\x18\n\x10\x64\x65\x66\x61ult_min_gpus\x18\n \x01(\x02\x12\x18\n\x10\x64\x65\x66\x61ult_max_gpus\x18\x0b \x01(\x02\"$\n\x07ShowSeq\x12\x19\n\x05shows\x18\x01 \x03(\x0b\x32\n.show.Show\"\x87\x02\n\tShowStats\x12\x16\n\x0erunning_frames\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65\x61\x64_frames\x18\x02 \x01(\x05\x12\x16\n\x0epending_frames\x18\x03 \x01(\x05\x12\x14\n\x0cpending_jobs\x18\x04 \x01(\x05\x12\x19\n\x11\x63reated_job_count\x18\x05 \x01(\x03\x12\x1b\n\x13\x63reated_frame_count\x18\x06 \x01(\x03\x12\x1c\n\x14rendered_frame_count\x18\x07 \x01(\x03\x12\x1a\n\x12\x66\x61iled_frame_count\x18\x08 \x01(\x03\x12\x16\n\x0ereserved_cores\x18\t \x01(\x02\x12\x15\n\rreserved_gpus\x18\n \x01(\x02\"A\n\x17ShowCreateFilterRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x18ShowCreateFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"@\n\x16ShowCreateOwnerRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x17ShowCreateOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"_\n ShowCreateServiceOverrideRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12!\n\x07service\x18\x02 \x01(\x0b\x32\x10.service.Service\"W\n!ShowCreateServiceOverrideResponse\x12\x32\n\x10service_override\x18\x01 \x01(\x0b\x32\x18.service.ServiceOverride\"%\n\x15ShowCreateShowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"2\n\x16ShowCreateShowResponse\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"m\n\x1dShowCreateSubscriptionRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x15\n\rallocation_id\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x02\x12\r\n\x05\x62urst\x18\x04 \x01(\x02\"R\n\x1eShowCreateSubscriptionResponse\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"-\n\x11ShowDeleteRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"\x14\n\x12ShowDeleteResponse\"E\n\x18ShowEnableBookingRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x1b\n\x19ShowEnableBookingResponse\"I\n\x1cShowEnableDispatchingRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x1f\n\x1dShowEnableDispatchingResponse\"?\n\x15ShowFindFilterRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\"8\n\x16ShowFindFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"#\n\x13ShowFindShowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x14ShowFindShowResponse\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"\x1b\n\x19ShowGetActiveShowsRequest\":\n\x1aShowGetActiveShowsResponse\x12\x1c\n\x05shows\x18\x01 \x01(\x0b\x32\r.show.ShowSeq\"/\n\x13ShowGetDeedsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"4\n\x14ShowGetDeedsResponse\x12\x1c\n\x05\x64\x65\x65\x64s\x18\x01 \x01(\x0b\x32\r.host.DeedSeq\"H\n\x18ShowGetDepartmentRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x12\n\ndepartment\x18\x02 \x01(\t\"G\n\x19ShowGetDepartmentResponse\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"5\n\x19ShowGetDepartmentsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"L\n\x1aShowGetDepartmentsResponse\x12.\n\x0b\x64\x65partments\x18\x01 \x01(\x0b\x32\x19.department.DepartmentSeq\"1\n\x15ShowGetFiltersRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"<\n\x16ShowGetFiltersResponse\x12\"\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x11.filter.FilterSeq\"0\n\x14ShowGetGroupsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"6\n\x15ShowGetGroupsResponse\x12\x1d\n\x06groups\x18\x01 \x01(\x0b\x32\r.job.GroupSeq\".\n\x12ShowGetJobsRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"0\n\x13ShowGetJobsResponse\x12\x19\n\x04jobs\x18\x01 \x01(\x0b\x32\x0b.job.JobSeq\"7\n\x1bShowGetJobWhiteboardRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"D\n\x1cShowGetJobWhiteboardResponse\x12$\n\nwhiteboard\x18\x01 \x01(\x0b\x32\x10.job.NestedGroup\"3\n\x17ShowGetRootGroupRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"5\n\x18ShowGetRootGroupResponse\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"G\n\x1dShowGetServiceOverrideRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x0c\n\x04name\x18\x02 \x01(\t\"T\n\x1eShowGetServiceOverrideResponse\x12\x32\n\x10service_override\x18\x01 \x01(\x0b\x32\x18.service.ServiceOverride\":\n\x1eShowGetServiceOverridesRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"Y\n\x1fShowGetServiceOverridesResponse\x12\x36\n\x11service_overrides\x18\x01 \x01(\x0b\x32\x1b.service.ServiceOverrideSeq\"\x15\n\x13ShowGetShowsRequest\"4\n\x14ShowGetShowsResponse\x12\x1c\n\x05shows\x18\x01 \x01(\x0b\x32\r.show.ShowSeq\"6\n\x1aShowGetSubscriptionRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\"S\n\x1bShowGetSubscriptionResponse\x12\x34\n\rsubscriptions\x18\x01 \x01(\x0b\x32\x1d.subscription.SubscriptionSeq\"?\n\x14ShowSetActiveRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\r\n\x05value\x18\x02 \x01(\x08\"\x17\n\x15ShowSetActiveResponse\"E\n\x1aShowSetCommentEmailRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x1d\n\x1bShowSetCommentEmailResponse\"L\n\x1dShowSetDefaultMaxCoresRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x11\n\tmax_cores\x18\x02 \x01(\x02\" \n\x1eShowSetDefaultMaxCoresResponse\"L\n\x1dShowSetDefaultMinCoresRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x11\n\tmin_cores\x18\x02 \x01(\x02\" \n\x1eShowSetDefaultMinCoresResponse\"J\n\x1cShowSetDefaultMaxGpusRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x10\n\x08max_gpus\x18\x02 \x01(\x05\"\x1f\n\x1dShowSetDefaultMaxGpusResponse\"J\n\x1cShowSetDefaultMinGpusRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x10\n\x08min_gpus\x18\x02 \x01(\x05\"\x1f\n\x1dShowSetDefaultMinGpusResponse\"H\n\x12ShowArchiveRequest\x12\x18\n\x04show\x18\x01 \x01(\x0b\x32\n.show.Show\x12\x18\n\x10target_show_name\x18\x02 \x01(\t\"\x15\n\x13ShowArchiveResponse2\xac\x13\n\rShowInterface\x12M\n\x0c\x43reateFilter\x12\x1d.show.ShowCreateFilterRequest\x1a\x1e.show.ShowCreateFilterResponse\x12J\n\x0b\x43reateOwner\x12\x1c.show.ShowCreateOwnerRequest\x1a\x1d.show.ShowCreateOwnerResponse\x12h\n\x15\x43reateServiceOverride\x12&.show.ShowCreateServiceOverrideRequest\x1a\'.show.ShowCreateServiceOverrideResponse\x12G\n\nCreateShow\x12\x1b.show.ShowCreateShowRequest\x1a\x1c.show.ShowCreateShowResponse\x12_\n\x12\x43reateSubscription\x12#.show.ShowCreateSubscriptionRequest\x1a$.show.ShowCreateSubscriptionResponse\x12;\n\x06\x44\x65lete\x12\x17.show.ShowDeleteRequest\x1a\x18.show.ShowDeleteResponse\x12P\n\rEnableBooking\x12\x1e.show.ShowEnableBookingRequest\x1a\x1f.show.ShowEnableBookingResponse\x12\\\n\x11\x45nableDispatching\x12\".show.ShowEnableDispatchingRequest\x1a#.show.ShowEnableDispatchingResponse\x12G\n\nFindFilter\x12\x1b.show.ShowFindFilterRequest\x1a\x1c.show.ShowFindFilterResponse\x12\x41\n\x08\x46indShow\x12\x19.show.ShowFindShowRequest\x1a\x1a.show.ShowFindShowResponse\x12S\n\x0eGetActiveShows\x12\x1f.show.ShowGetActiveShowsRequest\x1a .show.ShowGetActiveShowsResponse\x12\x41\n\x08GetDeeds\x12\x19.show.ShowGetDeedsRequest\x1a\x1a.show.ShowGetDeedsResponse\x12P\n\rGetDepartment\x12\x1e.show.ShowGetDepartmentRequest\x1a\x1f.show.ShowGetDepartmentResponse\x12S\n\x0eGetDepartments\x12\x1f.show.ShowGetDepartmentsRequest\x1a .show.ShowGetDepartmentsResponse\x12G\n\nGetFilters\x12\x1b.show.ShowGetFiltersRequest\x1a\x1c.show.ShowGetFiltersResponse\x12\x44\n\tGetGroups\x12\x1a.show.ShowGetGroupsRequest\x1a\x1b.show.ShowGetGroupsResponse\x12>\n\x07GetJobs\x12\x18.show.ShowGetJobsRequest\x1a\x19.show.ShowGetJobsResponse\x12Y\n\x10GetJobWhiteboard\x12!.show.ShowGetJobWhiteboardRequest\x1a\".show.ShowGetJobWhiteboardResponse\x12M\n\x0cGetRootGroup\x12\x1d.show.ShowGetRootGroupRequest\x1a\x1e.show.ShowGetRootGroupResponse\x12_\n\x12GetServiceOverride\x12#.show.ShowGetServiceOverrideRequest\x1a$.show.ShowGetServiceOverrideResponse\x12\x62\n\x13GetServiceOverrides\x12$.show.ShowGetServiceOverridesRequest\x1a%.show.ShowGetServiceOverridesResponse\x12\x41\n\x08GetShows\x12\x19.show.ShowGetShowsRequest\x1a\x1a.show.ShowGetShowsResponse\x12W\n\x10GetSubscriptions\x12 .show.ShowGetSubscriptionRequest\x1a!.show.ShowGetSubscriptionResponse\x12\x44\n\tSetActive\x12\x1a.show.ShowSetActiveRequest\x1a\x1b.show.ShowSetActiveResponse\x12V\n\x0fSetCommentEmail\x12 .show.ShowSetCommentEmailRequest\x1a!.show.ShowSetCommentEmailResponse\x12_\n\x12SetDefaultMaxCores\x12#.show.ShowSetDefaultMaxCoresRequest\x1a$.show.ShowSetDefaultMaxCoresResponse\x12_\n\x12SetDefaultMinCores\x12#.show.ShowSetDefaultMinCoresRequest\x1a$.show.ShowSetDefaultMinCoresResponse\x12\\\n\x11SetDefaultMaxGpus\x12\".show.ShowSetDefaultMaxGpusRequest\x1a#.show.ShowSetDefaultMaxGpusResponse\x12\\\n\x11SetDefaultMinGpus\x12\".show.ShowSetDefaultMinGpusRequest\x1a#.show.ShowSetDefaultMinGpusResponse\x12>\n\x07\x41rchive\x12\x18.show.ShowArchiveRequest\x1a\x19.show.ShowArchiveResponseB:\n\x1e\x63om.imageworks.spcue.grpc.showP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'show_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.imageworks.spcue.grpc.showP\001Z\026opencue_gateway/gen/go'
  _globals['_SHOW']._serialized_start=111
  _globals['_SHOW']._serialized_end=376
  _globals['_SHOWSEQ']._serialized_start=378
  _globals['_SHOWSEQ']._serialized_end=414
  _globals['_SHOWSTATS']._serialized_start=417
  _globals['_SHOWSTATS']._serialized_end=680
  _globals['_SHOWCREATEFILTERREQUEST']._serialized_start=682
  _globals['_SHOWCREATEFILTERREQUEST']._serialized_end=747
  _globals['_SHOWCREATEFILTERRESPONSE']._serialized_start=749
  _globals['_SHOWCREATEFILTERRESPONSE']._serialized_end=807
  _globals['_SHOWCREATEOWNERREQUEST']._serialized_start=809
  _globals['_SHOWCREATEOWNERREQUEST']._serialized_end=873
  _globals['_SHOWCREATEOWNERRESPONSE']._serialized_start=875
  _globals['_SHOWCREATEOWNERRESPONSE']._serialized_end=928
  _globals['_SHOWCREATESERVICEOVERRIDEREQUEST']._serialized_start=930
  _globals['_SHOWCREATESERVICEOVERRIDEREQUEST']._serialized_end=1025
  _globals['_SHOWCREATESERVICEOVERRIDERESPONSE']._serialized_start=1027
  _globals['_SHOWCREATESERVICEOVERRIDERESPONSE']._serialized_end=1114
  _globals['_SHOWCREATESHOWREQUEST']._serialized_start=1116
  _globals['_SHOWCREATESHOWREQUEST']._serialized_end=1153
  _globals['_SHOWCREATESHOWRESPONSE']._serialized_start=1155
  _globals['_SHOWCREATESHOWRESPONSE']._serialized_end=1205
  _globals['_SHOWCREATESUBSCRIPTIONREQUEST']._serialized_start=1207
  _globals['_SHOWCREATESUBSCRIPTIONREQUEST']._serialized_end=1316
  _globals['_SHOWCREATESUBSCRIPTIONRESPONSE']._serialized_start=1318
  _globals['_SHOWCREATESUBSCRIPTIONRESPONSE']._serialized_end=1400
  _globals['_SHOWDELETEREQUEST']._serialized_start=1402
  _globals['_SHOWDELETEREQUEST']._serialized_end=1447
  _globals['_SHOWDELETERESPONSE']._serialized_start=1449
  _globals['_SHOWDELETERESPONSE']._serialized_end=1469
  _globals['_SHOWENABLEBOOKINGREQUEST']._serialized_start=1471
  _globals['_SHOWENABLEBOOKINGREQUEST']._serialized_end=1540
  _globals['_SHOWENABLEBOOKINGRESPONSE']._serialized_start=1542
  _globals['_SHOWENABLEBOOKINGRESPONSE']._serialized_end=1569
  _globals['_SHOWENABLEDISPATCHINGREQUEST']._serialized_start=1571
  _globals['_SHOWENABLEDISPATCHINGREQUEST']._serialized_end=1644
  _globals['_SHOWENABLEDISPATCHINGRESPONSE']._serialized_start=1646
  _globals['_SHOWENABLEDISPATCHINGRESPONSE']._serialized_end=1677
  _globals['_SHOWFINDFILTERREQUEST']._serialized_start=1679
  _globals['_SHOWFINDFILTERREQUEST']._serialized_end=1742
  _globals['_SHOWFINDFILTERRESPONSE']._serialized_start=1744
  _globals['_SHOWFINDFILTERRESPONSE']._serialized_end=1800
  _globals['_SHOWFINDSHOWREQUEST']._serialized_start=1802
  _globals['_SHOWFINDSHOWREQUEST']._serialized_end=1837
  _globals['_SHOWFINDSHOWRESPONSE']._serialized_start=1839
  _globals['_SHOWFINDSHOWRESPONSE']._serialized_end=1887
  _globals['_SHOWGETACTIVESHOWSREQUEST']._serialized_start=1889
  _globals['_SHOWGETACTIVESHOWSREQUEST']._serialized_end=1916
  _globals['_SHOWGETACTIVESHOWSRESPONSE']._serialized_start=1918
  _globals['_SHOWGETACTIVESHOWSRESPONSE']._serialized_end=1976
  _globals['_SHOWGETDEEDSREQUEST']._serialized_start=1978
  _globals['_SHOWGETDEEDSREQUEST']._serialized_end=2025
  _globals['_SHOWGETDEEDSRESPONSE']._serialized_start=2027
  _globals['_SHOWGETDEEDSRESPONSE']._serialized_end=2079
  _globals['_SHOWGETDEPARTMENTREQUEST']._serialized_start=2081
  _globals['_SHOWGETDEPARTMENTREQUEST']._serialized_end=2153
  _globals['_SHOWGETDEPARTMENTRESPONSE']._serialized_start=2155
  _globals['_SHOWGETDEPARTMENTRESPONSE']._serialized_end=2226
  _globals['_SHOWGETDEPARTMENTSREQUEST']._serialized_start=2228
  _globals['_SHOWGETDEPARTMENTSREQUEST']._serialized_end=2281
  _globals['_SHOWGETDEPARTMENTSRESPONSE']._serialized_start=2283
  _globals['_SHOWGETDEPARTMENTSRESPONSE']._serialized_end=2359
  _globals['_SHOWGETFILTERSREQUEST']._serialized_start=2361
  _globals['_SHOWGETFILTERSREQUEST']._serialized_end=2410
  _globals['_SHOWGETFILTERSRESPONSE']._serialized_start=2412
  _globals['_SHOWGETFILTERSRESPONSE']._serialized_end=2472
  _globals['_SHOWGETGROUPSREQUEST']._serialized_start=2474
  _globals['_SHOWGETGROUPSREQUEST']._serialized_end=2522
  _globals['_SHOWGETGROUPSRESPONSE']._serialized_start=2524
  _globals['_SHOWGETGROUPSRESPONSE']._serialized_end=2578
  _globals['_SHOWGETJOBSREQUEST']._serialized_start=2580
  _globals['_SHOWGETJOBSREQUEST']._serialized_end=2626
  _globals['_SHOWGETJOBSRESPONSE']._serialized_start=2628
  _globals['_SHOWGETJOBSRESPONSE']._serialized_end=2676
  _globals['_SHOWGETJOBWHITEBOARDREQUEST']._serialized_start=2678
  _globals['_SHOWGETJOBWHITEBOARDREQUEST']._serialized_end=2733
  _globals['_SHOWGETJOBWHITEBOARDRESPONSE']._serialized_start=2735
  _globals['_SHOWGETJOBWHITEBOARDRESPONSE']._serialized_end=2803
  _globals['_SHOWGETROOTGROUPREQUEST']._serialized_start=2805
  _globals['_SHOWGETROOTGROUPREQUEST']._serialized_end=2856
  _globals['_SHOWGETROOTGROUPRESPONSE']._serialized_start=2858
  _globals['_SHOWGETROOTGROUPRESPONSE']._serialized_end=2911
  _globals['_SHOWGETSERVICEOVERRIDEREQUEST']._serialized_start=2913
  _globals['_SHOWGETSERVICEOVERRIDEREQUEST']._serialized_end=2984
  _globals['_SHOWGETSERVICEOVERRIDERESPONSE']._serialized_start=2986
  _globals['_SHOWGETSERVICEOVERRIDERESPONSE']._serialized_end=3070
  _globals['_SHOWGETSERVICEOVERRIDESREQUEST']._serialized_start=3072
  _globals['_SHOWGETSERVICEOVERRIDESREQUEST']._serialized_end=3130
  _globals['_SHOWGETSERVICEOVERRIDESRESPONSE']._serialized_start=3132
  _globals['_SHOWGETSERVICEOVERRIDESRESPONSE']._serialized_end=3221
  _globals['_SHOWGETSHOWSREQUEST']._serialized_start=3223
  _globals['_SHOWGETSHOWSREQUEST']._serialized_end=3244
  _globals['_SHOWGETSHOWSRESPONSE']._serialized_start=3246
  _globals['_SHOWGETSHOWSRESPONSE']._serialized_end=3298
  _globals['_SHOWGETSUBSCRIPTIONREQUEST']._serialized_start=3300
  _globals['_SHOWGETSUBSCRIPTIONREQUEST']._serialized_end=3354
  _globals['_SHOWGETSUBSCRIPTIONRESPONSE']._serialized_start=3356
  _globals['_SHOWGETSUBSCRIPTIONRESPONSE']._serialized_end=3439
  _globals['_SHOWSETACTIVEREQUEST']._serialized_start=3441
  _globals['_SHOWSETACTIVEREQUEST']._serialized_end=3504
  _globals['_SHOWSETACTIVERESPONSE']._serialized_start=3506
  _globals['_SHOWSETACTIVERESPONSE']._serialized_end=3529
  _globals['_SHOWSETCOMMENTEMAILREQUEST']._serialized_start=3531
  _globals['_SHOWSETCOMMENTEMAILREQUEST']._serialized_end=3600
  _globals['_SHOWSETCOMMENTEMAILRESPONSE']._serialized_start=3602
  _globals['_SHOWSETCOMMENTEMAILRESPONSE']._serialized_end=3631
  _globals['_SHOWSETDEFAULTMAXCORESREQUEST']._serialized_start=3633
  _globals['_SHOWSETDEFAULTMAXCORESREQUEST']._serialized_end=3709
  _globals['_SHOWSETDEFAULTMAXCORESRESPONSE']._serialized_start=3711
  _globals['_SHOWSETDEFAULTMAXCORESRESPONSE']._serialized_end=3743
  _globals['_SHOWSETDEFAULTMINCORESREQUEST']._serialized_start=3745
  _globals['_SHOWSETDEFAULTMINCORESREQUEST']._serialized_end=3821
  _globals['_SHOWSETDEFAULTMINCORESRESPONSE']._serialized_start=3823
  _globals['_SHOWSETDEFAULTMINCORESRESPONSE']._serialized_end=3855
  _globals['_SHOWSETDEFAULTMAXGPUSREQUEST']._serialized_start=3857
  _globals['_SHOWSETDEFAULTMAXGPUSREQUEST']._serialized_end=3931
  _globals['_SHOWSETDEFAULTMAXGPUSRESPONSE']._serialized_start=3933
  _globals['_SHOWSETDEFAULTMAXGPUSRESPONSE']._serialized_end=3964
  _globals['_SHOWSETDEFAULTMINGPUSREQUEST']._serialized_start=3966
  _globals['_SHOWSETDEFAULTMINGPUSREQUEST']._serialized_end=4040
  _globals['_SHOWSETDEFAULTMINGPUSRESPONSE']._serialized_start=4042
  _globals['_SHOWSETDEFAULTMINGPUSRESPONSE']._serialized_end=4073
  _globals['_SHOWARCHIVEREQUEST']._serialized_start=4075
  _globals['_SHOWARCHIVEREQUEST']._serialized_end=4147
  _globals['_SHOWARCHIVERESPONSE']._serialized_start=4149
  _globals['_SHOWARCHIVERESPONSE']._serialized_end=4170
  _globals['_SHOWINTERFACE']._serialized_start=4173
  _globals['_SHOWINTERFACE']._serialized_end=6649
# @@protoc_insertion_point(module_scope)