# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: depend.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64\x65pend.proto\x12\x06\x64\x65pend\"\x91\x02\n\x06\x44\x65pend\x12\n\n\x02id\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.depend.DependType\x12$\n\x06target\x18\x03 \x01(\x0e\x32\x14.depend.DependTarget\x12\x11\n\tany_frame\x18\x04 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x15\n\rdepend_er_job\x18\x06 \x01(\t\x12\x17\n\x0f\x64\x65pend_er_layer\x18\x07 \x01(\t\x12\x17\n\x0f\x64\x65pend_er_frame\x18\x08 \x01(\t\x12\x15\n\rdepend_on_job\x18\t \x01(\t\x12\x17\n\x0f\x64\x65pend_on_layer\x18\n \x01(\t\x12\x17\n\x0f\x64\x65pend_on_frame\x18\x0b \x01(\t\",\n\tDependSeq\x12\x1f\n\x07\x64\x65pends\x18\x01 \x03(\x0b\x32\x0e.depend.Depend\"$\n\x16\x44\x65pendGetDependRequest\x12\n\n\x02id\x18\x01 \x01(\t\"9\n\x17\x44\x65pendGetDependResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"6\n\x14\x44\x65pendSatisfyRequest\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"\x17\n\x15\x44\x65pendSatisfyResponse\"8\n\x16\x44\x65pendUnsatisfyRequest\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"\x19\n\x17\x44\x65pendUnsatisfyResponse*\xf4\x01\n\nDependType\x12\x0e\n\nJOB_ON_JOB\x10\x00\x12\x10\n\x0cJOB_ON_LAYER\x10\x01\x12\x10\n\x0cJOB_ON_FRAME\x10\x02\x12\x10\n\x0cLAYER_ON_JOB\x10\x03\x12\x12\n\x0eLAYER_ON_LAYER\x10\x04\x12\x12\n\x0eLAYER_ON_FRAME\x10\x05\x12\x10\n\x0c\x46RAME_ON_JOB\x10\x06\x12\x12\n\x0e\x46RAME_ON_LAYER\x10\x07\x12\x12\n\x0e\x46RAME_ON_FRAME\x10\x08\x12\x12\n\x0e\x46RAME_BY_FRAME\x10\t\x12\x12\n\x0ePREVIOUS_FRAME\x10\n\x12\x16\n\x12LAYER_ON_SIM_FRAME\x10\x0b*:\n\x0c\x44\x65pendTarget\x12\x0c\n\x08INTERNAL\x10\x00\x12\x0c\n\x08\x45XTERNAL\x10\x01\x12\x0e\n\nANY_TARGET\x10\x02\x32\xf5\x01\n\x0f\x44\x65pendInterface\x12L\n\tGetDepend\x12\x1e.depend.DependGetDependRequest\x1a\x1f.depend.DependGetDependResponse\x12\x46\n\x07Satisfy\x12\x1c.depend.DependSatisfyRequest\x1a\x1d.depend.DependSatisfyResponse\x12L\n\tUnsatisfy\x12\x1e.depend.DependUnsatisfyRequest\x1a\x1f.depend.DependUnsatisfyResponseB<\n com.imageworks.spcue.grpc.dependP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'depend_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.imageworks.spcue.grpc.dependP\001Z\026opencue_gateway/gen/go'
  _globals['_DEPENDTYPE']._serialized_start=610
  _globals['_DEPENDTYPE']._serialized_end=854
  _globals['_DEPENDTARGET']._serialized_start=856
  _globals['_DEPENDTARGET']._serialized_end=914
  _globals['_DEPEND']._serialized_start=25
  _globals['_DEPEND']._serialized_end=298
  _globals['_DEPENDSEQ']._serialized_start=300
  _globals['_DEPENDSEQ']._serialized_end=344
  _globals['_DEPENDGETDEPENDREQUEST']._serialized_start=346
  _globals['_DEPENDGETDEPENDREQUEST']._serialized_end=382
  _globals['_DEPENDGETDEPENDRESPONSE']._serialized_start=384
  _globals['_DEPENDGETDEPENDRESPONSE']._serialized_end=441
  _globals['_DEPENDSATISFYREQUEST']._serialized_start=443
  _globals['_DEPENDSATISFYREQUEST']._serialized_end=497
  _globals['_DEPENDSATISFYRESPONSE']._serialized_start=499
  _globals['_DEPENDSATISFYRESPONSE']._serialized_end=522
  _globals['_DEPENDUNSATISFYREQUEST']._serialized_start=524
  _globals['_DEPENDUNSATISFYREQUEST']._serialized_end=580
  _globals['_DEPENDUNSATISFYRESPONSE']._serialized_start=582
  _globals['_DEPENDUNSATISFYRESPONSE']._serialized_end=607
  _globals['_DEPENDINTERFACE']._serialized_start=917
  _globals['_DEPENDINTERFACE']._serialized_end=1162
# @@protoc_insertion_point(module_scope)