# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: limit.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0blimit.proto\x12\x05limit\"M\n\x05Limit\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmax_value\x18\x03 \x01(\x05\x12\x17\n\x0f\x63urrent_running\x18\x04 \x01(\x05\"5\n\x12LimitCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmax_value\x18\x02 \x01(\x05\"2\n\x13LimitCreateResponse\x12\x1b\n\x05limit\x18\x01 \x01(\x0b\x32\x0c.limit.Limit\"\"\n\x12LimitDeleteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x15\n\x13LimitDeleteResponse\" \n\x10LimitFindRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x11LimitFindResponse\x12\x1b\n\x05limit\x18\x01 \x01(\x0b\x32\x0c.limit.Limit\"\x1d\n\x0fLimitGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x10LimitGetResponse\x12\x1b\n\x05limit\x18\x01 \x01(\x0b\x32\x0c.limit.Limit\"\x14\n\x12LimitGetAllRequest\"3\n\x13LimitGetAllResponse\x12\x1c\n\x06limits\x18\x01 \x03(\x0b\x32\x0c.limit.Limit\"8\n\x12LimitRenameRequest\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x15\n\x13LimitRenameResponse\":\n\x17LimitSetMaxValueRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmax_value\x18\x02 \x01(\x05\"\x1a\n\x18LimitSetMaxValueResponse2\xd7\x03\n\x0eLimitInterface\x12?\n\x06\x43reate\x12\x19.limit.LimitCreateRequest\x1a\x1a.limit.LimitCreateResponse\x12?\n\x06\x44\x65lete\x12\x19.limit.LimitDeleteRequest\x1a\x1a.limit.LimitDeleteResponse\x12\x39\n\x04\x46ind\x12\x17.limit.LimitFindRequest\x1a\x18.limit.LimitFindResponse\x12\x36\n\x03Get\x12\x16.limit.LimitGetRequest\x1a\x17.limit.LimitGetResponse\x12?\n\x06GetAll\x12\x19.limit.LimitGetAllRequest\x1a\x1a.limit.LimitGetAllResponse\x12?\n\x06Rename\x12\x19.limit.LimitRenameRequest\x1a\x1a.limit.LimitRenameResponse\x12N\n\x0bSetMaxValue\x12\x1e.limit.LimitSetMaxValueRequest\x1a\x1f.limit.LimitSetMaxValueResponseB;\n\x1f\x63om.imageworks.spcue.grpc.limitP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.imageworks.spcue.grpc.limitP\001Z\026opencue_gateway/gen/go'
  _globals['_LIMIT']._serialized_start=22
  _globals['_LIMIT']._serialized_end=99
  _globals['_LIMITCREATEREQUEST']._serialized_start=101
  _globals['_LIMITCREATEREQUEST']._serialized_end=154
  _globals['_LIMITCREATERESPONSE']._serialized_start=156
  _globals['_LIMITCREATERESPONSE']._serialized_end=206
  _globals['_LIMITDELETEREQUEST']._serialized_start=208
  _globals['_LIMITDELETEREQUEST']._serialized_end=242
  _globals['_LIMITDELETERESPONSE']._serialized_start=244
  _globals['_LIMITDELETERESPONSE']._serialized_end=265
  _globals['_LIMITFINDREQUEST']._serialized_start=267
  _globals['_LIMITFINDREQUEST']._serialized_end=299
  _globals['_LIMITFINDRESPONSE']._serialized_start=301
  _globals['_LIMITFINDRESPONSE']._serialized_end=349
  _globals['_LIMITGETREQUEST']._serialized_start=351
  _globals['_LIMITGETREQUEST']._serialized_end=380
  _globals['_LIMITGETRESPONSE']._serialized_start=382
  _globals['_LIMITGETRESPONSE']._serialized_end=429
  _globals['_LIMITGETALLREQUEST']._serialized_start=431
  _globals['_LIMITGETALLREQUEST']._serialized_end=451
  _globals['_LIMITGETALLRESPONSE']._serialized_start=453
  _globals['_LIMITGETALLRESPONSE']._serialized_end=504
  _globals['_LIMITRENAMEREQUEST']._serialized_start=506
  _globals['_LIMITRENAMEREQUEST']._serialized_end=562
  _globals['_LIMITRENAMERESPONSE']._serialized_start=564
  _globals['_LIMITRENAMERESPONSE']._serialized_end=585
  _globals['_LIMITSETMAXVALUEREQUEST']._serialized_start=587
  _globals['_LIMITSETMAXVALUEREQUEST']._serialized_end=645
  _globals['_LIMITSETMAXVALUERESPONSE']._serialized_start=647
  _globals['_LIMITSETMAXVALUERESPONSE']._serialized_end=673
  _globals['_LIMITINTERFACE']._serialized_start=676
  _globals['_LIMITINTERFACE']._serialized_end=1147
# @@protoc_insertion_point(module_scope)