# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: host.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import comment_pb2 as comment__pb2
from . import criterion_pb2 as criterion__pb2
from . import job_pb2 as job__pb2
from . import renderPartition_pb2 as renderPartition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nhost.proto\x12\x04host\x1a\rcomment.proto\x1a\x0f\x63riterion.proto\x1a\tjob.proto\x1a\x15renderPartition.proto\"=\n\x04\x44\x65\x65\x64\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0c\n\x04show\x18\x04 \x01(\t\"$\n\x07\x44\x65\x65\x64Seq\x12\x19\n\x05\x64\x65\x65\x64s\x18\x01 \x03(\x0b\x32\n.host.Deed\"6\n\x10HardwareStateSeq\x12\"\n\x05state\x18\x01 \x03(\x0e\x32\x13.host.HardwareState\".\n\x0cLockStateSeq\x12\x1e\n\x05state\x18\x01 \x03(\x0e\x32\x0f.host.LockState\"\xde\x04\n\x04Host\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nalloc_name\x18\x03 \x01(\t\x12\x15\n\rnimby_enabled\x18\x04 \x01(\x08\x12\x13\n\x0bhas_comment\x18\x05 \x01(\x08\x12\r\n\x05\x63ores\x18\x06 \x01(\x02\x12\x12\n\nidle_cores\x18\x07 \x01(\x02\x12\x0e\n\x06memory\x18\x08 \x01(\x03\x12\x13\n\x0bidle_memory\x18\t \x01(\x03\x12\x12\n\ngpu_memory\x18\n \x01(\x03\x12\x17\n\x0fidle_gpu_memory\x18\x0b \x01(\x03\x12\x12\n\ntotal_swap\x18\x0c \x01(\x03\x12\x14\n\x0ctotal_memory\x18\r \x01(\x03\x12\x18\n\x10total_gpu_memory\x18\x0e \x01(\x03\x12\x11\n\ttotal_mcp\x18\x0f \x01(\x03\x12\x11\n\tfree_swap\x18\x10 \x01(\x03\x12\x13\n\x0b\x66ree_memory\x18\x11 \x01(\x03\x12\x10\n\x08\x66ree_mcp\x18\x12 \x01(\x03\x12\x17\n\x0f\x66ree_gpu_memory\x18\x13 \x01(\x03\x12\x0c\n\x04load\x18\x14 \x01(\x05\x12\x11\n\tboot_time\x18\x15 \x01(\x05\x12\x11\n\tping_time\x18\x16 \x01(\x05\x12\n\n\x02os\x18\x17 \x01(\t\x12\x0c\n\x04tags\x18\x18 \x03(\t\x12\"\n\x05state\x18\x19 \x01(\x0e\x32\x13.host.HardwareState\x12#\n\nlock_state\x18\x1a \x01(\x0e\x32\x0f.host.LockState\x12%\n\x0bthread_mode\x18\x1b \x01(\x0e\x32\x10.host.ThreadMode\x12\x0c\n\x04gpus\x18\x1c \x01(\x02\x12\x11\n\tidle_gpus\x18\x1d \x01(\x02\"\xb0\x01\n\x12HostSearchCriteria\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\r\n\x05regex\x18\x02 \x03(\t\x12\x0e\n\x06substr\x18\x03 \x03(\t\x12\x0b\n\x03ids\x18\x04 \x03(\t\x12\x0e\n\x06\x61llocs\x18\x05 \x03(\t\x12&\n\x06states\x18\x06 \x01(\x0b\x32\x16.host.HardwareStateSeq\x12\'\n\x0block_states\x18\x07 \x01(\x0b\x32\x12.host.LockStateSeq\"$\n\x07HostSeq\x12\x19\n\x05hosts\x18\x01 \x03(\x0b\x32\n.host.Host\"\x88\x05\n\nNestedHost\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nalloc_name\x18\x03 \x01(\t\x12\x15\n\rnimby_enabled\x18\x04 \x01(\x08\x12\x13\n\x0bhas_comment\x18\x05 \x01(\x08\x12\r\n\x05\x63ores\x18\x06 \x01(\x02\x12\x12\n\nidle_cores\x18\x07 \x01(\x02\x12\x0e\n\x06memory\x18\x08 \x01(\x03\x12\x13\n\x0bidle_memory\x18\t \x01(\x03\x12\x12\n\ngpu_memory\x18\n \x01(\x03\x12\x17\n\x0fidle_gpu_memory\x18\x0b \x01(\x03\x12\x12\n\ntotal_swap\x18\x0c \x01(\x03\x12\x14\n\x0ctotal_memory\x18\r \x01(\x03\x12\x18\n\x10total_gpu_memory\x18\x0e \x01(\x03\x12\x11\n\ttotal_mcp\x18\x0f \x01(\x03\x12\x11\n\tfree_swap\x18\x10 \x01(\x03\x12\x13\n\x0b\x66ree_memory\x18\x11 \x01(\x03\x12\x10\n\x08\x66ree_mcp\x18\x12 \x01(\x03\x12\x17\n\x0f\x66ree_gpu_memory\x18\x13 \x01(\x03\x12\x0c\n\x04load\x18\x14 \x01(\x05\x12\x11\n\tboot_time\x18\x15 \x01(\x05\x12\x11\n\tping_time\x18\x16 \x01(\x05\x12\n\n\x02os\x18\x17 \x01(\t\x12\x0c\n\x04tags\x18\x18 \x03(\t\x12\"\n\x05state\x18\x19 \x01(\x0e\x32\x13.host.HardwareState\x12#\n\nlock_state\x18\x1a \x01(\x0e\x32\x0f.host.LockState\x12%\n\x0bthread_mode\x18\x1b \x01(\x0e\x32\x10.host.ThreadMode\x12\"\n\x05procs\x18\x1c \x01(\x0b\x32\x13.host.NestedProcSeq\x12\x0c\n\x04gpus\x18\x1d \x01(\x02\x12\x11\n\tidle_gpus\x18\x1e \x01(\x02\"7\n\rNestedHostSeq\x12&\n\x0cnested_hosts\x18\x01 \x03(\x0b\x32\x10.host.NestedHost\"\xb5\x03\n\nNestedProc\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tshow_name\x18\x03 \x01(\t\x12\x10\n\x08job_name\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x12\n\ngroup_name\x18\x06 \x01(\t\x12\x11\n\tping_time\x18\x07 \x01(\x05\x12\x12\n\nbookedTime\x18\x08 \x01(\x05\x12\x15\n\rdispatch_time\x18\t \x01(\x05\x12\x17\n\x0freserved_memory\x18\n \x01(\x03\x12\x1b\n\x13reserved_gpu_memory\x18\x0b \x01(\x03\x12\x13\n\x0bused_memory\x18\x0c \x01(\x03\x12\x16\n\x0ereserved_cores\x18\r \x01(\x02\x12\x10\n\x08unbooked\x18\x0e \x01(\x08\x12\x10\n\x08log_path\x18\x0f \x01(\t\x12\x17\n\x0fredirect_target\x18\x10 \x01(\t\x12\x10\n\x08services\x18\x11 \x03(\t\x12 \n\x06parent\x18\x12 \x01(\x0b\x32\x10.host.NestedHost\x12\x17\n\x0fused_gpu_memory\x18\x13 \x01(\x03\x12\x15\n\rreserved_gpus\x18\x14 \x01(\x02\"7\n\rNestedProcSeq\x12&\n\x0cnested_procs\x18\x01 \x03(\x0b\x32\x10.host.NestedProc\"C\n\x05Owner\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04show\x18\x03 \x01(\t\x12\x12\n\nhost_count\x18\x04 \x01(\x05\"\xa6\x03\n\x04Proc\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tshow_name\x18\x03 \x01(\t\x12\x10\n\x08job_name\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x12\n\ngroup_name\x18\x06 \x01(\t\x12\x11\n\tping_time\x18\x07 \x01(\x05\x12\x12\n\nbookedTime\x18\x08 \x01(\x05\x12\x15\n\rdispatch_time\x18\t \x01(\x05\x12\x17\n\x0freserved_memory\x18\n \x01(\x03\x12\x1b\n\x13reserved_gpu_memory\x18\x0b \x01(\x03\x12\x13\n\x0bused_memory\x18\x0c \x01(\x03\x12\x16\n\x0ereserved_cores\x18\r \x01(\x02\x12\x10\n\x08unbooked\x18\x0e \x01(\x08\x12\x10\n\x08log_path\x18\x0f \x01(\t\x12\x17\n\x0fredirect_target\x18\x10 \x01(\t\x12\x10\n\x08services\x18\x11 \x03(\t\x12\x17\n\x0fused_gpu_memory\x18\x12 \x01(\x03\x12\x15\n\rreserved_gpus\x18\x13 \x01(\x02\x12\x17\n\x0f\x63hild_processes\x18\x14 \x01(\x0c\"\xa0\x03\n\x12ProcSearchCriteria\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x0c\n\x04jobs\x18\x02 \x03(\t\x12\x0e\n\x06layers\x18\x03 \x03(\t\x12\r\n\x05shows\x18\x04 \x03(\t\x12\x0e\n\x06\x61llocs\x18\x05 \x03(\t\x12>\n\x0cmemory_range\x18\x06 \x03(\x0b\x32(.criterion.InRangeIntegerSearchCriterion\x12I\n\x13memory_greater_than\x18\n \x03(\x0b\x32,.criterion.GreaterThanIntegerSearchCriterion\x12\x46\n\x10memory_less_than\x18\x0b \x03(\x0b\x32,.criterion.GreaterThanIntegerSearchCriterion\x12@\n\x0e\x64uration_range\x18\x07 \x03(\x0b\x32(.criterion.InRangeIntegerSearchCriterion\x12\x13\n\x0bmax_results\x18\x08 \x03(\x05\x12\x14\n\x0c\x66irst_result\x18\t \x01(\x05\"$\n\x07ProcSeq\x12\x19\n\x05procs\x18\x01 \x03(\x0b\x32\n.host.Proc\"-\n\x11\x44\x65\x65\x64\x44\x65leteRequest\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\"\x14\n\x12\x44\x65\x65\x64\x44\x65leteResponse\".\n\x12\x44\x65\x65\x64GetHostRequest\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\"/\n\x13\x44\x65\x65\x64GetHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"/\n\x13\x44\x65\x65\x64GetOwnerRequest\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\"2\n\x14\x44\x65\x65\x64GetOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"X\n\x15HostAddCommentRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12%\n\x0bnew_comment\x18\x02 \x01(\x0b\x32\x10.comment.Comment\"\x18\n\x16HostAddCommentResponse\"<\n\x12HostAddTagsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x15\n\x13HostAddTagsResponse\"-\n\x11HostDeleteRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x14\n\x12HostDeleteResponse\"#\n\x13HostFindHostRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x14HostFindHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"2\n\x16HostGetCommentsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"@\n\x17HostGetCommentsResponse\x12%\n\x08\x63omments\x18\x01 \x01(\x0b\x32\x13.comment.CommentSeq\".\n\x12HostGetDeedRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"/\n\x13HostGetDeedResponse\x12\x18\n\x04\x64\x65\x65\x64\x18\x01 \x01(\x0b\x32\n.host.Deed\" \n\x12HostGetHostRequest\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x13HostGetHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\":\n\x13HostGetHostsRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.HostSearchCriteria\"4\n\x14HostGetHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"\x1e\n\x1cHostGetHostWhiteboardRequest\"J\n\x1dHostGetHostWhiteboardResponse\x12)\n\x0cnested_hosts\x18\x01 \x01(\x0b\x32\x13.host.NestedHostSeq\"/\n\x13HostGetOwnerRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"2\n\x14HostGetOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"/\n\x13HostGetProcsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"4\n\x14HostGetProcsResponse\x12\x1c\n\x05procs\x18\x01 \x01(\x0b\x32\r.host.ProcSeq\":\n\x1eHostGetRenderPartitionsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"a\n\x1fHostGetRenderPartitionsResponse\x12>\n\x11render_partitions\x18\x01 \x01(\x0b\x32#.renderPartition.RenderPartitionSeq\"+\n\x0fHostLockRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x12\n\x10HostLockResponse\"-\n\x11HostRebootRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x14\n\x12HostRebootResponse\"5\n\x19HostRebootWhenIdleRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x1c\n\x1aHostRebootWhenIdleResponse\"X\n\x18HostRedirectToJobRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x12\n\nproc_names\x18\x02 \x03(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\"*\n\x19HostRedirectToJobResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"?\n\x15HostRemoveTagsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x18\n\x16HostRemoveTagsResponse\"R\n\x14HostRenameTagRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x0f\n\x07old_tag\x18\x02 \x01(\t\x12\x0f\n\x07new_tag\x18\x03 \x01(\t\"\x17\n\x15HostRenameTagResponse\"K\n\x18HostSetAllocationRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x15\n\rallocation_id\x18\x02 \x01(\t\"\x1b\n\x19HostSetAllocationResponse\"[\n\x1bHostSetHardwareStateRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\"\n\x05state\x18\x02 \x01(\x0e\x32\x13.host.HardwareState\"\x1e\n\x1cHostSetHardwareStateResponse\"8\n\x10HostSetOsRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\n\n\x02os\x18\x02 \x01(\t\"\x13\n\x11HostSetOsResponse\"T\n\x18HostSetThreadModeRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\x12\x1e\n\x04mode\x18\x02 \x01(\x0e\x32\x10.host.ThreadMode\"\x1b\n\x19HostSetThreadModeResponse\"-\n\x11HostUnlockRequest\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"\x14\n\x12HostUnlockResponse\"0\n\x12OwnerDeleteRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"\x15\n\x13OwnerDeleteResponse\"2\n\x14OwnerGetDeedsRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"5\n\x15OwnerGetDeedsResponse\x12\x1c\n\x05\x64\x65\x65\x64s\x18\x01 \x01(\x0b\x32\r.host.DeedSeq\"2\n\x14OwnerGetHostsRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"5\n\x15OwnerGetHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"$\n\x14OwnerGetOwnerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"3\n\x15OwnerGetOwnerResponse\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\"?\n\x13OwnerSetShowRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\x12\x0c\n\x04show\x18\x02 \x01(\t\"\x16\n\x14OwnerSetShowResponse\"E\n\x19OwnerTakeOwnershipRequest\x12\x1a\n\x05owner\x18\x01 \x01(\x0b\x32\x0b.host.Owner\x12\x0c\n\x04host\x18\x02 \x01(\t\"\x1c\n\x1aOwnerTakeOwnershipResponse\"4\n\x18ProcClearRedirectRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"*\n\x19ProcClearRedirectResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"/\n\x13ProcGetFrameRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"1\n\x14ProcGetFrameResponse\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\".\n\x12ProcGetHostRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"/\n\x13ProcGetHostResponse\x12\x18\n\x04host\x18\x01 \x01(\x0b\x32\n.host.Host\"-\n\x11ProcGetJobRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"+\n\x12ProcGetJobResponse\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"/\n\x13ProcGetLayerRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"1\n\x14ProcGetLayerResponse\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\":\n\x13ProcGetProcsRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\"4\n\x14ProcGetProcsResponse\x12\x1c\n\x05procs\x18\x01 \x01(\x0b\x32\r.host.ProcSeq\"+\n\x0fProcKillRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\"\x12\n\x10ProcKillResponse\"V\n\x1aProcRedirectToGroupRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12\x0c\n\x04kill\x18\x03 \x01(\x08\",\n\x1bProcRedirectToGroupResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"R\n\x18ProcRedirectToJobRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x0c\n\x04kill\x18\x03 \x01(\x08\"*\n\x19ProcRedirectToJobResponse\x12\r\n\x05value\x18\x01 \x01(\x08\";\n\x11ProcUnbookRequest\x12\x18\n\x04proc\x18\x01 \x01(\x0b\x32\n.host.Proc\x12\x0c\n\x04kill\x18\x02 \x01(\x08\"\x14\n\x12ProcUnbookResponse\"K\n\x16ProcUnbookProcsRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\x12\x0c\n\x04kill\x18\x02 \x01(\x08\",\n\x17ProcUnbookProcsResponse\x12\x11\n\tnum_procs\x18\x01 \x01(\x05\"f\n\x16ProcUnbookToJobRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\x12\x19\n\x04jobs\x18\x02 \x01(\x0b\x32\x0b.job.JobSeq\x12\x0c\n\x04kill\x18\x03 \x01(\x08\",\n\x17ProcUnbookToJobResponse\x12\x11\n\tnum_procs\x18\x01 \x01(\x05\"h\n\x18ProcUnbookToGroupRequest\x12#\n\x01r\x18\x01 \x01(\x0b\x32\x18.host.ProcSearchCriteria\x12\x19\n\x05group\x18\x02 \x01(\x0b\x32\n.job.Group\x12\x0c\n\x04kill\x18\x03 \x01(\x08\".\n\x19ProcUnbookToGroupResponse\x12\x11\n\tnum_procs\x18\x01 \x01(\x05*R\n\rHardwareState\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\r\n\tREBOOTING\x10\x02\x12\x14\n\x10REBOOT_WHEN_IDLE\x10\x03\x12\n\n\x06REPAIR\x10\x04*@\n\x0bHostTagType\x12\n\n\x06MANUAL\x10\x00\x12\x0c\n\x08HARDWARE\x10\x01\x12\t\n\x05\x41LLOC\x10\x02\x12\x0c\n\x08HOSTNAME\x10\x03*3\n\tLockState\x12\x08\n\x04OPEN\x10\x00\x12\n\n\x06LOCKED\x10\x01\x12\x10\n\x0cNIMBY_LOCKED\x10\x02*4\n\x0cRedirectType\x12\x10\n\x0cJOB_REDIRECT\x10\x00\x12\x12\n\x0eGROUP_REDIRECT\x10\x01* \n\x08RunState\x12\x08\n\x04IDLE\x10\x00\x12\n\n\x06\x42OOKED\x10\x01*-\n\nThreadMode\x12\x08\n\x04\x41UTO\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x0c\n\x08VARIABLE\x10\x02\x32\xcf\x01\n\rDeedInterface\x12;\n\x06\x44\x65lete\x12\x17.host.DeedDeleteRequest\x1a\x18.host.DeedDeleteResponse\x12>\n\x07GetHost\x12\x18.host.DeedGetHostRequest\x1a\x19.host.DeedGetHostResponse\x12\x41\n\x08GetOwner\x12\x19.host.DeedGetOwnerRequest\x1a\x1a.host.DeedGetOwnerResponse2\x8f\r\n\rHostInterface\x12G\n\nAddComment\x12\x1b.host.HostAddCommentRequest\x1a\x1c.host.HostAddCommentResponse\x12>\n\x07\x41\x64\x64Tags\x12\x18.host.HostAddTagsRequest\x1a\x19.host.HostAddTagsResponse\x12;\n\x06\x44\x65lete\x12\x17.host.HostDeleteRequest\x1a\x18.host.HostDeleteResponse\x12\x41\n\x08\x46indHost\x12\x19.host.HostFindHostRequest\x1a\x1a.host.HostFindHostResponse\x12J\n\x0bGetComments\x12\x1c.host.HostGetCommentsRequest\x1a\x1d.host.HostGetCommentsResponse\x12>\n\x07GetDeed\x12\x18.host.HostGetDeedRequest\x1a\x19.host.HostGetDeedResponse\x12>\n\x07GetHost\x12\x18.host.HostGetHostRequest\x1a\x19.host.HostGetHostResponse\x12\x41\n\x08GetHosts\x12\x19.host.HostGetHostsRequest\x1a\x1a.host.HostGetHostsResponse\x12\\\n\x11GetHostWhiteboard\x12\".host.HostGetHostWhiteboardRequest\x1a#.host.HostGetHostWhiteboardResponse\x12\x41\n\x08GetOwner\x12\x19.host.HostGetOwnerRequest\x1a\x1a.host.HostGetOwnerResponse\x12\x41\n\x08GetProcs\x12\x19.host.HostGetProcsRequest\x1a\x1a.host.HostGetProcsResponse\x12\x62\n\x13GetRenderPartitions\x12$.host.HostGetRenderPartitionsRequest\x1a%.host.HostGetRenderPartitionsResponse\x12\x35\n\x04Lock\x12\x15.host.HostLockRequest\x1a\x16.host.HostLockResponse\x12;\n\x06Reboot\x12\x17.host.HostRebootRequest\x1a\x18.host.HostRebootResponse\x12S\n\x0eRebootWhenIdle\x12\x1f.host.HostRebootWhenIdleRequest\x1a .host.HostRebootWhenIdleResponse\x12P\n\rRedirectToJob\x12\x1e.host.HostRedirectToJobRequest\x1a\x1f.host.HostRedirectToJobResponse\x12G\n\nRemoveTags\x12\x1b.host.HostRemoveTagsRequest\x1a\x1c.host.HostRemoveTagsResponse\x12\x44\n\tRenameTag\x12\x1a.host.HostRenameTagRequest\x1a\x1b.host.HostRenameTagResponse\x12P\n\rSetAllocation\x12\x1e.host.HostSetAllocationRequest\x1a\x1f.host.HostSetAllocationResponse\x12Y\n\x10SetHardwareState\x12!.host.HostSetHardwareStateRequest\x1a\".host.HostSetHardwareStateResponse\x12\x38\n\x05SetOs\x12\x16.host.HostSetOsRequest\x1a\x17.host.HostSetOsResponse\x12P\n\rSetThreadMode\x12\x1e.host.HostSetThreadModeRequest\x1a\x1f.host.HostSetThreadModeResponse\x12;\n\x06Unlock\x12\x17.host.HostUnlockRequest\x1a\x18.host.HostUnlockResponse2\xb4\x03\n\x0eOwnerInterface\x12=\n\x06\x44\x65lete\x12\x18.host.OwnerDeleteRequest\x1a\x19.host.OwnerDeleteResponse\x12\x43\n\x08GetDeeds\x12\x1a.host.OwnerGetDeedsRequest\x1a\x1b.host.OwnerGetDeedsResponse\x12\x43\n\x08GetHosts\x12\x1a.host.OwnerGetHostsRequest\x1a\x1b.host.OwnerGetHostsResponse\x12\x43\n\x08GetOwner\x12\x1a.host.OwnerGetOwnerRequest\x1a\x1b.host.OwnerGetOwnerResponse\x12@\n\x07SetShow\x12\x19.host.OwnerSetShowRequest\x1a\x1a.host.OwnerSetShowResponse\x12R\n\rTakeOwnership\x12\x1f.host.OwnerTakeOwnershipRequest\x1a .host.OwnerTakeOwnershipResponse2\xaf\x07\n\rProcInterface\x12P\n\rClearRedirect\x12\x1e.host.ProcClearRedirectRequest\x1a\x1f.host.ProcClearRedirectResponse\x12\x41\n\x08GetFrame\x12\x19.host.ProcGetFrameRequest\x1a\x1a.host.ProcGetFrameResponse\x12>\n\x07GetHost\x12\x18.host.ProcGetHostRequest\x1a\x19.host.ProcGetHostResponse\x12;\n\x06GetJob\x12\x17.host.ProcGetJobRequest\x1a\x18.host.ProcGetJobResponse\x12\x41\n\x08GetLayer\x12\x19.host.ProcGetLayerRequest\x1a\x1a.host.ProcGetLayerResponse\x12\x41\n\x08GetProcs\x12\x19.host.ProcGetProcsRequest\x1a\x1a.host.ProcGetProcsResponse\x12\x35\n\x04Kill\x12\x15.host.ProcKillRequest\x1a\x16.host.ProcKillResponse\x12V\n\x0fRedirectToGroup\x12 .host.ProcRedirectToGroupRequest\x1a!.host.ProcRedirectToGroupResponse\x12P\n\rRedirectToJob\x12\x1e.host.ProcRedirectToJobRequest\x1a\x1f.host.ProcRedirectToJobResponse\x12;\n\x06Unbook\x12\x17.host.ProcUnbookRequest\x1a\x18.host.ProcUnbookResponse\x12J\n\x0bUnbookProcs\x12\x1c.host.ProcUnbookProcsRequest\x1a\x1d.host.ProcUnbookProcsResponse\x12P\n\rUnbookToGroup\x12\x1e.host.ProcUnbookToGroupRequest\x1a\x1f.host.ProcUnbookToGroupResponse\x12J\n\x0bUnbookToJob\x12\x1c.host.ProcUnbookToJobRequest\x1a\x1d.host.ProcUnbookToJobResponseB:\n\x1e\x63om.imageworks.spcue.grpc.hostP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.imageworks.spcue.grpc.hostP\001Z\026opencue_gateway/gen/go'
  _globals['_HARDWARESTATE']._serialized_start=7833
  _globals['_HARDWARESTATE']._serialized_end=7915
  _globals['_HOSTTAGTYPE']._serialized_start=7917
  _globals['_HOSTTAGTYPE']._serialized_end=7981
  _globals['_LOCKSTATE']._serialized_start=7983
  _globals['_LOCKSTATE']._serialized_end=8034
  _globals['_REDIRECTTYPE']._serialized_start=8036
  _globals['_REDIRECTTYPE']._serialized_end=8088
  _globals['_RUNSTATE']._serialized_start=8090
  _globals['_RUNSTATE']._serialized_end=8122
  _globals['_THREADMODE']._serialized_start=8124
  _globals['_THREADMODE']._serialized_end=8169
  _globals['_DEED']._serialized_start=86
  _globals['_DEED']._serialized_end=147
  _globals['_DEEDSEQ']._serialized_start=149
  _globals['_DEEDSEQ']._serialized_end=185
  _globals['_HARDWARESTATESEQ']._serialized_start=187
  _globals['_HARDWARESTATESEQ']._serialized_end=241
  _globals['_LOCKSTATESEQ']._serialized_start=243
  _globals['_LOCKSTATESEQ']._serialized_end=289
  _globals['_HOST']._serialized_start=292
  _globals['_HOST']._serialized_end=898
  _globals['_HOSTSEARCHCRITERIA']._serialized_start=901
  _globals['_HOSTSEARCHCRITERIA']._serialized_end=1077
  _globals['_HOSTSEQ']._serialized_start=1079
  _globals['_HOSTSEQ']._serialized_end=1115
  _globals['_NESTEDHOST']._serialized_start=1118
  _globals['_NESTEDHOST']._serialized_end=1766
  _globals['_NESTEDHOSTSEQ']._serialized_start=1768
  _globals['_NESTEDHOSTSEQ']._serialized_end=1823
  _globals['_NESTEDPROC']._serialized_start=1826
  _globals['_NESTEDPROC']._serialized_end=2263
  _globals['_NESTEDPROCSEQ']._serialized_start=2265
  _globals['_NESTEDPROCSEQ']._serialized_end=2320
  _globals['_OWNER']._serialized_start=2322
  _globals['_OWNER']._serialized_end=2389
  _globals['_PROC']._serialized_start=2392
  _globals['_PROC']._serialized_end=2814
  _globals['_PROCSEARCHCRITERIA']._serialized_start=2817
  _globals['_PROCSEARCHCRITERIA']._serialized_end=3233
  _globals['_PROCSEQ']._serialized_start=3235
  _globals['_PROCSEQ']._serialized_end=3271
  _globals['_DEEDDELETEREQUEST']._serialized_start=3273
  _globals['_DEEDDELETEREQUEST']._serialized_end=3318
  _globals['_DEEDDELETERESPONSE']._serialized_start=3320
  _globals['_DEEDDELETERESPONSE']._serialized_end=3340
  _globals['_DEEDGETHOSTREQUEST']._serialized_start=3342
  _globals['_DEEDGETHOSTREQUEST']._serialized_end=3388
  _globals['_DEEDGETHOSTRESPONSE']._serialized_start=3390
  _globals['_DEEDGETHOSTRESPONSE']._serialized_end=3437
  _globals['_DEEDGETOWNERREQUEST']._serialized_start=3439
  _globals['_DEEDGETOWNERREQUEST']._serialized_end=3486
  _globals['_DEEDGETOWNERRESPONSE']._serialized_start=3488
  _globals['_DEEDGETOWNERRESPONSE']._serialized_end=3538
  _globals['_HOSTADDCOMMENTREQUEST']._serialized_start=3540
  _globals['_HOSTADDCOMMENTREQUEST']._serialized_end=3628
  _globals['_HOSTADDCOMMENTRESPONSE']._serialized_start=3630
  _globals['_HOSTADDCOMMENTRESPONSE']._serialized_end=3654
  _globals['_HOSTADDTAGSREQUEST']._serialized_start=3656
  _globals['_HOSTADDTAGSREQUEST']._serialized_end=3716
  _globals['_HOSTADDTAGSRESPONSE']._serialized_start=3718
  _globals['_HOSTADDTAGSRESPONSE']._serialized_end=3739
  _globals['_HOSTDELETEREQUEST']._serialized_start=3741
  _globals['_HOSTDELETEREQUEST']._serialized_end=3786
  _globals['_HOSTDELETERESPONSE']._serialized_start=3788
  _globals['_HOSTDELETERESPONSE']._serialized_end=3808
  _globals['_HOSTFINDHOSTREQUEST']._serialized_start=3810
  _globals['_HOSTFINDHOSTREQUEST']._serialized_end=3845
  _globals['_HOSTFINDHOSTRESPONSE']._serialized_start=3847
  _globals['_HOSTFINDHOSTRESPONSE']._serialized_end=3895
  _globals['_HOSTGETCOMMENTSREQUEST']._serialized_start=3897
  _globals['_HOSTGETCOMMENTSREQUEST']._serialized_end=3947
  _globals['_HOSTGETCOMMENTSRESPONSE']._serialized_start=3949
  _globals['_HOSTGETCOMMENTSRESPONSE']._serialized_end=4013
  _globals['_HOSTGETDEEDREQUEST']._serialized_start=4015
  _globals['_HOSTGETDEEDREQUEST']._serialized_end=4061
  _globals['_HOSTGETDEEDRESPONSE']._serialized_start=4063
  _globals['_HOSTGETDEEDRESPONSE']._serialized_end=4110
  _globals['_HOSTGETHOSTREQUEST']._serialized_start=4112
  _globals['_HOSTGETHOSTREQUEST']._serialized_end=4144
  _globals['_HOSTGETHOSTRESPONSE']._serialized_start=4146
  _globals['_HOSTGETHOSTRESPONSE']._serialized_end=4193
  _globals['_HOSTGETHOSTSREQUEST']._serialized_start=4195
  _globals['_HOSTGETHOSTSREQUEST']._serialized_end=4253
  _globals['_HOSTGETHOSTSRESPONSE']._serialized_start=4255
  _globals['_HOSTGETHOSTSRESPONSE']._serialized_end=4307
  _globals['_HOSTGETHOSTWHITEBOARDREQUEST']._serialized_start=4309
  _globals['_HOSTGETHOSTWHITEBOARDREQUEST']._serialized_end=4339
  _globals['_HOSTGETHOSTWHITEBOARDRESPONSE']._serialized_start=4341
  _globals['_HOSTGETHOSTWHITEBOARDRESPONSE']._serialized_end=4415
  _globals['_HOSTGETOWNERREQUEST']._serialized_start=4417
  _globals['_HOSTGETOWNERREQUEST']._serialized_end=4464
  _globals['_HOSTGETOWNERRESPONSE']._serialized_start=4466
  _globals['_HOSTGETOWNERRESPONSE']._serialized_end=4516
  _globals['_HOSTGETPROCSREQUEST']._serialized_start=4518
  _globals['_HOSTGETPROCSREQUEST']._serialized_end=4565
  _globals['_HOSTGETPROCSRESPONSE']._serialized_start=4567
  _globals['_HOSTGETPROCSRESPONSE']._serialized_end=4619
  _globals['_HOSTGETRENDERPARTITIONSREQUEST']._serialized_start=4621
  _globals['_HOSTGETRENDERPARTITIONSREQUEST']._serialized_end=4679
  _globals['_HOSTGETRENDERPARTITIONSRESPONSE']._serialized_start=4681
  _globals['_HOSTGETRENDERPARTITIONSRESPONSE']._serialized_end=4778
  _globals['_HOSTLOCKREQUEST']._serialized_start=4780
  _globals['_HOSTLOCKREQUEST']._serialized_end=4823
  _globals['_HOSTLOCKRESPONSE']._serialized_start=4825
  _globals['_HOSTLOCKRESPONSE']._serialized_end=4843
  _globals['_HOSTREBOOTREQUEST']._serialized_start=4845
  _globals['_HOSTREBOOTREQUEST']._serialized_end=4890
  _globals['_HOSTREBOOTRESPONSE']._serialized_start=4892
  _globals['_HOSTREBOOTRESPONSE']._serialized_end=4912
  _globals['_HOSTREBOOTWHENIDLEREQUEST']._serialized_start=4914
  _globals['_HOSTREBOOTWHENIDLEREQUEST']._serialized_end=4967
  _globals['_HOSTREBOOTWHENIDLERESPONSE']._serialized_start=4969
  _globals['_HOSTREBOOTWHENIDLERESPONSE']._serialized_end=4997
  _globals['_HOSTREDIRECTTOJOBREQUEST']._serialized_start=4999
  _globals['_HOSTREDIRECTTOJOBREQUEST']._serialized_end=5087
  _globals['_HOSTREDIRECTTOJOBRESPONSE']._serialized_start=5089
  _globals['_HOSTREDIRECTTOJOBRESPONSE']._serialized_end=5131
  _globals['_HOSTREMOVETAGSREQUEST']._serialized_start=5133
  _globals['_HOSTREMOVETAGSREQUEST']._serialized_end=5196
  _globals['_HOSTREMOVETAGSRESPONSE']._serialized_start=5198
  _globals['_HOSTREMOVETAGSRESPONSE']._serialized_end=5222
  _globals['_HOSTRENAMETAGREQUEST']._serialized_start=5224
  _globals['_HOSTRENAMETAGREQUEST']._serialized_end=5306
  _globals['_HOSTRENAMETAGRESPONSE']._serialized_start=5308
  _globals['_HOSTRENAMETAGRESPONSE']._serialized_end=5331
  _globals['_HOSTSETALLOCATIONREQUEST']._serialized_start=5333
  _globals['_HOSTSETALLOCATIONREQUEST']._serialized_end=5408
  _globals['_HOSTSETALLOCATIONRESPONSE']._serialized_start=5410
  _globals['_HOSTSETALLOCATIONRESPONSE']._serialized_end=5437
  _globals['_HOSTSETHARDWARESTATEREQUEST']._serialized_start=5439
  _globals['_HOSTSETHARDWARESTATEREQUEST']._serialized_end=5530
  _globals['_HOSTSETHARDWARESTATERESPONSE']._serialized_start=5532
  _globals['_HOSTSETHARDWARESTATERESPONSE']._serialized_end=5562
  _globals['_HOSTSETOSREQUEST']._serialized_start=5564
  _globals['_HOSTSETOSREQUEST']._serialized_end=5620
  _globals['_HOSTSETOSRESPONSE']._serialized_start=5622
  _globals['_HOSTSETOSRESPONSE']._serialized_end=5641
  _globals['_HOSTSETTHREADMODEREQUEST']._serialized_start=5643
  _globals['_HOSTSETTHREADMODEREQUEST']._serialized_end=5727
  _globals['_HOSTSETTHREADMODERESPONSE']._serialized_start=5729
  _globals['_HOSTSETTHREADMODERESPONSE']._serialized_end=5756
  _globals['_HOSTUNLOCKREQUEST']._serialized_start=5758
  _globals['_HOSTUNLOCKREQUEST']._serialized_end=5803
  _globals['_HOSTUNLOCKRESPONSE']._serialized_start=5805
  _globals['_HOSTUNLOCKRESPONSE']._serialized_end=5825
  _globals['_OWNERDELETEREQUEST']._serialized_start=5827
  _globals['_OWNERDELETEREQUEST']._serialized_end=5875
  _globals['_OWNERDELETERESPONSE']._serialized_start=5877
  _globals['_OWNERDELETERESPONSE']._serialized_end=5898
  _globals['_OWNERGETDEEDSREQUEST']._serialized_start=5900
  _globals['_OWNERGETDEEDSREQUEST']._serialized_end=5950
  _globals['_OWNERGETDEEDSRESPONSE']._serialized_start=5952
  _globals['_OWNERGETDEEDSRESPONSE']._serialized_end=6005
  _globals['_OWNERGETHOSTSREQUEST']._serialized_start=6007
  _globals['_OWNERGETHOSTSREQUEST']._serialized_end=6057
  _globals['_OWNERGETHOSTSRESPONSE']._serialized_start=6059
  _globals['_OWNERGETHOSTSRESPONSE']._serialized_end=6112
  _globals['_OWNERGETOWNERREQUEST']._serialized_start=6114
  _globals['_OWNERGETOWNERREQUEST']._serialized_end=6150
  _globals['_OWNERGETOWNERRESPONSE']._serialized_start=6152
  _globals['_OWNERGETOWNERRESPONSE']._serialized_end=6203
  _globals['_OWNERSETSHOWREQUEST']._serialized_start=6205
  _globals['_OWNERSETSHOWREQUEST']._serialized_end=6268
  _globals['_OWNERSETSHOWRESPONSE']._serialized_start=6270
  _globals['_OWNERSETSHOWRESPONSE']._serialized_end=6292
  _globals['_OWNERTAKEOWNERSHIPREQUEST']._serialized_start=6294
  _globals['_OWNERTAKEOWNERSHIPREQUEST']._serialized_end=6363
  _globals['_OWNERTAKEOWNERSHIPRESPONSE']._serialized_start=6365
  _globals['_OWNERTAKEOWNERSHIPRESPONSE']._serialized_end=6393
  _globals['_PROCCLEARREDIRECTREQUEST']._serialized_start=6395
  _globals['_PROCCLEARREDIRECTREQUEST']._serialized_end=6447
  _globals['_PROCCLEARREDIRECTRESPONSE']._serialized_start=6449
  _globals['_PROCCLEARREDIRECTRESPONSE']._serialized_end=6491
  _globals['_PROCGETFRAMEREQUEST']._serialized_start=6493
  _globals['_PROCGETFRAMEREQUEST']._serialized_end=6540
  _globals['_PROCGETFRAMERESPONSE']._serialized_start=6542
  _globals['_PROCGETFRAMERESPONSE']._serialized_end=6591
  _globals['_PROCGETHOSTREQUEST']._serialized_start=6593
  _globals['_PROCGETHOSTREQUEST']._serialized_end=6639
  _globals['_PROCGETHOSTRESPONSE']._serialized_start=6641
  _globals['_PROCGETHOSTRESPONSE']._serialized_end=6688
  _globals['_PROCGETJOBREQUEST']._serialized_start=6690
  _globals['_PROCGETJOBREQUEST']._serialized_end=6735
  _globals['_PROCGETJOBRESPONSE']._serialized_start=6737
  _globals['_PROCGETJOBRESPONSE']._serialized_end=6780
  _globals['_PROCGETLAYERREQUEST']._serialized_start=6782
  _globals['_PROCGETLAYERREQUEST']._serialized_end=6829
  _globals['_PROCGETLAYERRESPONSE']._serialized_start=6831
  _globals['_PROCGETLAYERRESPONSE']._serialized_end=6880
  _globals['_PROCGETPROCSREQUEST']._serialized_start=6882
  _globals['_PROCGETPROCSREQUEST']._serialized_end=6940
  _globals['_PROCGETPROCSRESPONSE']._serialized_start=6942
  _globals['_PROCGETPROCSRESPONSE']._serialized_end=6994
  _globals['_PROCKILLREQUEST']._serialized_start=6996
  _globals['_PROCKILLREQUEST']._serialized_end=7039
  _globals['_PROCKILLRESPONSE']._serialized_start=7041
  _globals['_PROCKILLRESPONSE']._serialized_end=7059
  _globals['_PROCREDIRECTTOGROUPREQUEST']._serialized_start=7061
  _globals['_PROCREDIRECTTOGROUPREQUEST']._serialized_end=7147
  _globals['_PROCREDIRECTTOGROUPRESPONSE']._serialized_start=7149
  _globals['_PROCREDIRECTTOGROUPRESPONSE']._serialized_end=7193
  _globals['_PROCREDIRECTTOJOBREQUEST']._serialized_start=7195
  _globals['_PROCREDIRECTTOJOBREQUEST']._serialized_end=7277
  _globals['_PROCREDIRECTTOJOBRESPONSE']._serialized_start=7279
  _globals['_PROCREDIRECTTOJOBRESPONSE']._serialized_end=7321
  _globals['_PROCUNBOOKREQUEST']._serialized_start=7323
  _globals['_PROCUNBOOKREQUEST']._serialized_end=7382
  _globals['_PROCUNBOOKRESPONSE']._serialized_start=7384
  _globals['_PROCUNBOOKRESPONSE']._serialized_end=7404
  _globals['_PROCUNBOOKPROCSREQUEST']._serialized_start=7406
  _globals['_PROCUNBOOKPROCSREQUEST']._serialized_end=7481
  _globals['_PROCUNBOOKPROCSRESPONSE']._serialized_start=7483
  _globals['_PROCUNBOOKPROCSRESPONSE']._serialized_end=7527
  _globals['_PROCUNBOOKTOJOBREQUEST']._serialized_start=7529
  _globals['_PROCUNBOOKTOJOBREQUEST']._serialized_end=7631
  _globals['_PROCUNBOOKTOJOBRESPONSE']._serialized_start=7633
  _globals['_PROCUNBOOKTOJOBRESPONSE']._serialized_end=7677
  _globals['_PROCUNBOOKTOGROUPREQUEST']._serialized_start=7679
  _globals['_PROCUNBOOKTOGROUPREQUEST']._serialized_end=7783
  _globals['_PROCUNBOOKTOGROUPRESPONSE']._serialized_start=7785
  _globals['_PROCUNBOOKTOGROUPRESPONSE']._serialized_end=7831
  _globals['_DEEDINTERFACE']._serialized_start=8172
  _globals['_DEEDINTERFACE']._serialized_end=8379
  _globals['_HOSTINTERFACE']._serialized_start=8382
  _globals['_HOSTINTERFACE']._serialized_end=10061
  _globals['_OWNERINTERFACE']._serialized_start=10064
  _globals['_OWNERINTERFACE']._serialized_end=10500
  _globals['_PROCINTERFACE']._serialized_start=10503
  _globals['_PROCINTERFACE']._serialized_end=11446
# @@protoc_insertion_point(module_scope)