# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: subscription.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12subscription.proto\x12\x0csubscription\"\xb2\x01\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tshow_name\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61\x63ility\x18\x04 \x01(\t\x12\x17\n\x0f\x61llocation_name\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x05\x12\r\n\x05\x62urst\x18\x07 \x01(\x05\x12\x16\n\x0ereserved_cores\x18\x08 \x01(\x05\x12\x15\n\rreserved_gpus\x18\t \x01(\x05\"D\n\x0fSubscriptionSeq\x12\x31\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x1a.subscription.Subscription\"M\n\x19SubscriptionDeleteRequest\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"\x1c\n\x1aSubscriptionDeleteResponse\"\'\n\x17SubscriptionFindRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"L\n\x18SubscriptionFindResponse\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"$\n\x16SubscriptionGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"K\n\x17SubscriptionGetResponse\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\"^\n\x1bSubscriptionSetBurstRequest\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\x12\r\n\x05\x62urst\x18\x02 \x01(\x05\"\x1e\n\x1cSubscriptionSetBurstResponse\"`\n\x1aSubscriptionSetSizeRequest\x12\x30\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1a.subscription.Subscription\x12\x10\n\x08new_size\x18\x02 \x01(\x05\"\x1d\n\x1bSubscriptionSetSizeResponse2\xe2\x03\n\x15SubscriptionInterface\x12[\n\x06\x44\x65lete\x12\'.subscription.SubscriptionDeleteRequest\x1a(.subscription.SubscriptionDeleteResponse\x12U\n\x04\x46ind\x12%.subscription.SubscriptionFindRequest\x1a&.subscription.SubscriptionFindResponse\x12R\n\x03Get\x12$.subscription.SubscriptionGetRequest\x1a%.subscription.SubscriptionGetResponse\x12\x61\n\x08SetBurst\x12).subscription.SubscriptionSetBurstRequest\x1a*.subscription.SubscriptionSetBurstResponse\x12^\n\x07SetSize\x12(.subscription.SubscriptionSetSizeRequest\x1a).subscription.SubscriptionSetSizeResponseBB\n&com.imageworks.spcue.grpc.subscriptionP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'subscription_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.imageworks.spcue.grpc.subscriptionP\001Z\026opencue_gateway/gen/go'
  _globals['_SUBSCRIPTION']._serialized_start=37
  _globals['_SUBSCRIPTION']._serialized_end=215
  _globals['_SUBSCRIPTIONSEQ']._serialized_start=217
  _globals['_SUBSCRIPTIONSEQ']._serialized_end=285
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_start=287
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_end=364
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_start=366
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_end=394
  _globals['_SUBSCRIPTIONFINDREQUEST']._serialized_start=396
  _globals['_SUBSCRIPTIONFINDREQUEST']._serialized_end=435
  _globals['_SUBSCRIPTIONFINDRESPONSE']._serialized_start=437
  _globals['_SUBSCRIPTIONFINDRESPONSE']._serialized_end=513
  _globals['_SUBSCRIPTIONGETREQUEST']._serialized_start=515
  _globals['_SUBSCRIPTIONGETREQUEST']._serialized_end=551
  _globals['_SUBSCRIPTIONGETRESPONSE']._serialized_start=553
  _globals['_SUBSCRIPTIONGETRESPONSE']._serialized_end=628
  _globals['_SUBSCRIPTIONSETBURSTREQUEST']._serialized_start=630
  _globals['_SUBSCRIPTIONSETBURSTREQUEST']._serialized_end=724
  _globals['_SUBSCRIPTIONSETBURSTRESPONSE']._serialized_start=726
  _globals['_SUBSCRIPTIONSETBURSTRESPONSE']._serialized_end=756
  _globals['_SUBSCRIPTIONSETSIZEREQUEST']._serialized_start=758
  _globals['_SUBSCRIPTIONSETSIZEREQUEST']._serialized_end=854
  _globals['_SUBSCRIPTIONSETSIZERESPONSE']._serialized_start=856
  _globals['_SUBSCRIPTIONSETSIZERESPONSE']._serialized_end=885
  _globals['_SUBSCRIPTIONINTERFACE']._serialized_start=888
  _globals['_SUBSCRIPTIONINTERFACE']._serialized_end=1370
# @@protoc_insertion_point(module_scope)