# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import cue_pb2 as cue__pb2


class CueInterfaceStub(object):
    """Core System level objects and methods

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetSystemStats = channel.unary_unary(
                '/cue.CueInterface/GetSystemStats',
                request_serializer=cue__pb2.CueGetSystemStatsRequest.SerializeToString,
                response_deserializer=cue__pb2.CueGetSystemStatsResponse.FromString,
                )


class CueInterfaceServicer(object):
    """Core System level objects and methods

    -------- Services --------]

    """

    def GetSystemStats(self, request, context):
        """returns the current server statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CueInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetSystemStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSystemStats,
                    request_deserializer=cue__pb2.CueGetSystemStatsRequest.FromString,
                    response_serializer=cue__pb2.CueGetSystemStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cue.CueInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CueInterface(object):
    """Core System level objects and methods

    -------- Services --------]

    """

    @staticmethod
    def GetSystemStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cue.CueInterface/GetSystemStats',
            cue__pb2.CueGetSystemStatsRequest.SerializeToString,
            cue__pb2.CueGetSystemStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)