# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cue.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tcue.proto\x12\x03\x63ue\"\xad\x07\n\x0bSystemStats\x12\x16\n\x0emanage_waiting\x18\x01 \x01(\x05\x12!\n\x19manage_remaining_capacity\x18\x02 \x01(\x05\x12\x16\n\x0emanage_threads\x18\x03 \x01(\x05\x12\x17\n\x0fmanage_executed\x18\x04 \x01(\x03\x12\x17\n\x0fmanage_rejected\x18\x05 \x01(\x03\x12\x18\n\x10\x64ispatch_waiting\x18\x06 \x01(\x05\x12#\n\x1b\x64ispatch_remaining_capacity\x18\x07 \x01(\x05\x12\x18\n\x10\x64ispatch_threads\x18\x08 \x01(\x05\x12\x19\n\x11\x64ispatch_executed\x18\t \x01(\x03\x12\x19\n\x11\x64ispatch_rejected\x18\n \x01(\x03\x12\x16\n\x0ereport_waiting\x18\x0b \x01(\x05\x12!\n\x19report_remaining_capacity\x18\x0c \x01(\x05\x12\x16\n\x0ereport_threads\x18\r \x01(\x05\x12\x17\n\x0freport_executed\x18\x0e \x01(\x03\x12\x17\n\x0freport_rejected\x18\x0f \x01(\x03\x12\x17\n\x0f\x62ooking_waiting\x18\x10 \x01(\x05\x12\"\n\x1a\x62ooking_remaining_capacity\x18\x11 \x01(\x05\x12\x17\n\x0f\x62ooking_threads\x18\x12 \x01(\x05\x12\x1c\n\x14\x62ooking_sleep_millis\x18\x13 \x01(\x05\x12\x18\n\x10\x62ooking_executed\x18\x14 \x01(\x03\x12\x18\n\x10\x62ooking_rejected\x18\x15 \x01(\x03\x12\x1c\n\x14host_balance_success\x18\x16 \x01(\x03\x12\x1b\n\x13host_balance_failed\x18\x17 \x01(\x03\x12\x1d\n\x15killed_offender_procs\x18\x18 \x01(\x03\x12\x18\n\x10killed_oom_procs\x18\x19 \x01(\x03\x12\x15\n\rcleared_procs\x18\x1a \x01(\x03\x12\x16\n\x0e\x62ooking_errors\x18\x1b \x01(\x03\x12\x17\n\x0f\x62ooking_retries\x18\x1c \x01(\x03\x12\x14\n\x0c\x62ooked_procs\x18\x1d \x01(\x03\x12\x14\n\x0creq_for_data\x18\x1e \x01(\x03\x12\x18\n\x10req_for_function\x18\x1f \x01(\x03\x12\x12\n\nreq_errors\x18  \x01(\x03\x12\x16\n\x0eunbooked_procs\x18! \x01(\x03\x12\x17\n\x0fpicked_up_cores\x18\" \x01(\x03\x12\x16\n\x0estranded_cores\x18# \x01(\x03\"\x1a\n\x18\x43ueGetSystemStatsRequest\"<\n\x19\x43ueGetSystemStatsResponse\x12\x1f\n\x05stats\x18\x01 \x01(\x0b\x32\x10.cue.SystemStats2_\n\x0c\x43ueInterface\x12O\n\x0eGetSystemStats\x12\x1d.cue.CueGetSystemStatsRequest\x1a\x1e.cue.CueGetSystemStatsResponseB9\n\x1d\x63om.imageworks.spcue.grpc.cueP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cue_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.imageworks.spcue.grpc.cueP\001Z\026opencue_gateway/gen/go'
  _globals['_SYSTEMSTATS']._serialized_start=19
  _globals['_SYSTEMSTATS']._serialized_end=960
  _globals['_CUEGETSYSTEMSTATSREQUEST']._serialized_start=962
  _globals['_CUEGETSYSTEMSTATSREQUEST']._serialized_end=988
  _globals['_CUEGETSYSTEMSTATSRESPONSE']._serialized_start=990
  _globals['_CUEGETSYSTEMSTATSRESPONSE']._serialized_end=1050
  _globals['_CUEINTERFACE']._serialized_start=1052
  _globals['_CUEINTERFACE']._serialized_end=1147
# @@protoc_insertion_point(module_scope)