# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: facility.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import host_pb2 as host__pb2
from . import subscription_pb2 as subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x66\x61\x63ility.proto\x12\x08\x66\x61\x63ility\x1a\nhost.proto\x1a\x12subscription.proto\"$\n\x08\x46\x61\x63ility\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x0b\x46\x61\x63ilitySeq\x12&\n\nfacilities\x18\x01 \x03(\x0b\x32\x12.facility.Facility\"\x81\x01\n\nAllocation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61\x63ility\x18\x04 \x01(\t\x12\x10\n\x08\x62illable\x18\x05 \x01(\x08\x12(\n\x05stats\x18\x06 \x01(\x0b\x32\x19.facility.AllocationStats\":\n\rAllocationSeq\x12)\n\x0b\x61llocations\x18\x01 \x03(\x0b\x32\x14.facility.Allocation\"\x97\x02\n\x0f\x41llocationStats\x12\r\n\x05\x63ores\x18\x01 \x01(\x02\x12\x17\n\x0f\x61vailable_cores\x18\x02 \x01(\x02\x12\x12\n\nidle_cores\x18\x03 \x01(\x02\x12\x15\n\rrunning_cores\x18\x04 \x01(\x02\x12\x14\n\x0clocked_cores\x18\x05 \x01(\x02\x12\r\n\x05hosts\x18\x06 \x01(\x05\x12\x14\n\x0clocked_hosts\x18\x07 \x01(\x05\x12\x12\n\ndown_hosts\x18\x08 \x01(\x05\x12\x0c\n\x04gpus\x18\t \x01(\x02\x12\x16\n\x0e\x61vailable_gpus\x18\n \x01(\x02\x12\x11\n\tidle_gpus\x18\x0b \x01(\x02\x12\x14\n\x0crunning_gpus\x18\x0c \x01(\x02\x12\x13\n\x0blocked_gpus\x18\r \x01(\x02\"%\n\x15\x46\x61\x63ilityCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\">\n\x16\x46\x61\x63ilityCreateResponse\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\"%\n\x15\x46\x61\x63ilityDeleteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16\x46\x61\x63ilityDeleteResponse\"E\n\x1d\x46\x61\x63ilityGetAllocationsRequest\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\"N\n\x1e\x46\x61\x63ilityGetAllocationsResponse\x12,\n\x0b\x61llocations\x18\x01 \x01(\x0b\x32\x17.facility.AllocationSeq\"\"\n\x12\x46\x61\x63ilityGetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\";\n\x13\x46\x61\x63ilityGetResponse\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\"O\n\x15\x46\x61\x63ilityRenameRequest\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x18\n\x16\x46\x61\x63ilityRenameResponse\"U\n\x12\x41llocCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12$\n\x08\x66\x61\x63ility\x18\x03 \x01(\x0b\x32\x12.facility.Facility\"?\n\x13\x41llocCreateResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\">\n\x12\x41llocDeleteRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"\x15\n\x13\x41llocDeleteResponse\" \n\x10\x41llocFindRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"=\n\x11\x41llocFindResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"f\n\x15\x41llocFindHostsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12#\n\x01r\x18\x02 \x01(\x0b\x32\x18.host.HostSearchCriteria\"6\n\x16\x41llocFindHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"\x1d\n\x0f\x41llocGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"<\n\x10\x41llocGetResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"\x14\n\x12\x41llocGetAllRequest\"C\n\x13\x41llocGetAllResponse\x12,\n\x0b\x61llocations\x18\x01 \x01(\x0b\x32\x17.facility.AllocationSeq\"@\n\x14\x41llocGetHostsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"5\n\x15\x41llocGetHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"H\n\x1c\x41llocGetSubscriptionsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"U\n\x1d\x41llocGetSubscriptionsResponse\x12\x34\n\rsubscriptions\x18\x01 \x01(\x0b\x32\x1d.subscription.SubscriptionSeq\"c\n\x19\x41llocReparentHostsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\x1c\n\x05hosts\x18\x02 \x01(\x0b\x32\r.host.HostSeq\"\x1c\n\x1a\x41llocReparentHostsResponse\"R\n\x17\x41llocSetBillableRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\r\n\x05value\x18\x02 \x01(\x08\"\x1a\n\x18\x41llocSetBillableResponse\"M\n\x13\x41llocSetNameRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x41llocSetNameResponse\"K\n\x12\x41llocSetTagRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\x15\n\x13\x41llocSetTagResponse\"\x18\n\x16\x41llocGetDefaultRequest\"C\n\x17\x41llocGetDefaultResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"B\n\x16\x41llocSetDefaultRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"\x19\n\x17\x41llocSetDefaultResponse2\xa3\x03\n\x11\x46\x61\x63ilityInterface\x12K\n\x06\x43reate\x12\x1f.facility.FacilityCreateRequest\x1a .facility.FacilityCreateResponse\x12K\n\x06\x44\x65lete\x12\x1f.facility.FacilityDeleteRequest\x1a .facility.FacilityDeleteResponse\x12\x42\n\x03Get\x12\x1c.facility.FacilityGetRequest\x1a\x1d.facility.FacilityGetResponse\x12K\n\x06Rename\x12\x1f.facility.FacilityRenameRequest\x1a .facility.FacilityRenameResponse\x12\x63\n\x0eGetAllocations\x12\'.facility.FacilityGetAllocationsRequest\x1a(.facility.FacilityGetAllocationsResponse2\xd6\x08\n\x13\x41llocationInterface\x12G\n\x06\x43reate\x12\x1c.facility.AllocCreateRequest\x1a\x1d.facility.AllocCreateResponse\"\x00\x12\x45\n\x06\x44\x65lete\x12\x1c.facility.AllocDeleteRequest\x1a\x1d.facility.AllocDeleteResponse\x12?\n\x04\x46ind\x12\x1a.facility.AllocFindRequest\x1a\x1b.facility.AllocFindResponse\x12N\n\tFindHosts\x12\x1f.facility.AllocFindHostsRequest\x1a .facility.AllocFindHostsResponse\x12<\n\x03Get\x12\x19.facility.AllocGetRequest\x1a\x1a.facility.AllocGetResponse\x12\x45\n\x06GetAll\x12\x1c.facility.AllocGetAllRequest\x1a\x1d.facility.AllocGetAllResponse\x12K\n\x08GetHosts\x12\x1e.facility.AllocGetHostsRequest\x1a\x1f.facility.AllocGetHostsResponse\x12\x63\n\x10GetSubscriptions\x12&.facility.AllocGetSubscriptionsRequest\x1a\'.facility.AllocGetSubscriptionsResponse\x12Z\n\rReparentHosts\x12#.facility.AllocReparentHostsRequest\x1a$.facility.AllocReparentHostsResponse\x12T\n\x0bSetBillable\x12!.facility.AllocSetBillableRequest\x1a\".facility.AllocSetBillableResponse\x12H\n\x07SetName\x12\x1d.facility.AllocSetNameRequest\x1a\x1e.facility.AllocSetNameResponse\x12\x45\n\x06SetTag\x12\x1c.facility.AllocSetTagRequest\x1a\x1d.facility.AllocSetTagResponse\x12Q\n\nGetDefault\x12 .facility.AllocGetDefaultRequest\x1a!.facility.AllocGetDefaultResponse\x12Q\n\nSetDefault\x12 .facility.AllocSetDefaultRequest\x1a!.facility.AllocSetDefaultResponseB>\n\"com.imageworks.spcue.grpc.facilityP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'facility_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.imageworks.spcue.grpc.facilityP\001Z\026opencue_gateway/gen/go'
  _globals['_FACILITY']._serialized_start=60
  _globals['_FACILITY']._serialized_end=96
  _globals['_FACILITYSEQ']._serialized_start=98
  _globals['_FACILITYSEQ']._serialized_end=151
  _globals['_ALLOCATION']._serialized_start=154
  _globals['_ALLOCATION']._serialized_end=283
  _globals['_ALLOCATIONSEQ']._serialized_start=285
  _globals['_ALLOCATIONSEQ']._serialized_end=343
  _globals['_ALLOCATIONSTATS']._serialized_start=346
  _globals['_ALLOCATIONSTATS']._serialized_end=625
  _globals['_FACILITYCREATEREQUEST']._serialized_start=627
  _globals['_FACILITYCREATEREQUEST']._serialized_end=664
  _globals['_FACILITYCREATERESPONSE']._serialized_start=666
  _globals['_FACILITYCREATERESPONSE']._serialized_end=728
  _globals['_FACILITYDELETEREQUEST']._serialized_start=730
  _globals['_FACILITYDELETEREQUEST']._serialized_end=767
  _globals['_FACILITYDELETERESPONSE']._serialized_start=769
  _globals['_FACILITYDELETERESPONSE']._serialized_end=793
  _globals['_FACILITYGETALLOCATIONSREQUEST']._serialized_start=795
  _globals['_FACILITYGETALLOCATIONSREQUEST']._serialized_end=864
  _globals['_FACILITYGETALLOCATIONSRESPONSE']._serialized_start=866
  _globals['_FACILITYGETALLOCATIONSRESPONSE']._serialized_end=944
  _globals['_FACILITYGETREQUEST']._serialized_start=946
  _globals['_FACILITYGETREQUEST']._serialized_end=980
  _globals['_FACILITYGETRESPONSE']._serialized_start=982
  _globals['_FACILITYGETRESPONSE']._serialized_end=1041
  _globals['_FACILITYRENAMEREQUEST']._serialized_start=1043
  _globals['_FACILITYRENAMEREQUEST']._serialized_end=1122
  _globals['_FACILITYRENAMERESPONSE']._serialized_start=1124
  _globals['_FACILITYRENAMERESPONSE']._serialized_end=1148
  _globals['_ALLOCCREATEREQUEST']._serialized_start=1150
  _globals['_ALLOCCREATEREQUEST']._serialized_end=1235
  _globals['_ALLOCCREATERESPONSE']._serialized_start=1237
  _globals['_ALLOCCREATERESPONSE']._serialized_end=1300
  _globals['_ALLOCDELETEREQUEST']._serialized_start=1302
  _globals['_ALLOCDELETEREQUEST']._serialized_end=1364
  _globals['_ALLOCDELETERESPONSE']._serialized_start=1366
  _globals['_ALLOCDELETERESPONSE']._serialized_end=1387
  _globals['_ALLOCFINDREQUEST']._serialized_start=1389
  _globals['_ALLOCFINDREQUEST']._serialized_end=1421
  _globals['_ALLOCFINDRESPONSE']._serialized_start=1423
  _globals['_ALLOCFINDRESPONSE']._serialized_end=1484
  _globals['_ALLOCFINDHOSTSREQUEST']._serialized_start=1486
  _globals['_ALLOCFINDHOSTSREQUEST']._serialized_end=1588
  _globals['_ALLOCFINDHOSTSRESPONSE']._serialized_start=1590
  _globals['_ALLOCFINDHOSTSRESPONSE']._serialized_end=1644
  _globals['_ALLOCGETREQUEST']._serialized_start=1646
  _globals['_ALLOCGETREQUEST']._serialized_end=1675
  _globals['_ALLOCGETRESPONSE']._serialized_start=1677
  _globals['_ALLOCGETRESPONSE']._serialized_end=1737
  _globals['_ALLOCGETALLREQUEST']._serialized_start=1739
  _globals['_ALLOCGETALLREQUEST']._serialized_end=1759
  _globals['_ALLOCGETALLRESPONSE']._serialized_start=1761
  _globals['_ALLOCGETALLRESPONSE']._serialized_end=1828
  _globals['_ALLOCGETHOSTSREQUEST']._serialized_start=1830
  _globals['_ALLOCGETHOSTSREQUEST']._serialized_end=1894
  _globals['_ALLOCGETHOSTSRESPONSE']._serialized_start=1896
  _globals['_ALLOCGETHOSTSRESPONSE']._serialized_end=1949
  _globals['_ALLOCGETSUBSCRIPTIONSREQUEST']._serialized_start=1951
  _globals['_ALLOCGETSUBSCRIPTIONSREQUEST']._serialized_end=2023
  _globals['_ALLOCGETSUBSCRIPTIONSRESPONSE']._serialized_start=2025
  _globals['_ALLOCGETSUBSCRIPTIONSRESPONSE']._serialized_end=2110
  _globals['_ALLOCREPARENTHOSTSREQUEST']._serialized_start=2112
  _globals['_ALLOCREPARENTHOSTSREQUEST']._serialized_end=2211
  _globals['_ALLOCREPARENTHOSTSRESPONSE']._serialized_start=2213
  _globals['_ALLOCREPARENTHOSTSRESPONSE']._serialized_end=2241
  _globals['_ALLOCSETBILLABLEREQUEST']._serialized_start=2243
  _globals['_ALLOCSETBILLABLEREQUEST']._serialized_end=2325
  _globals['_ALLOCSETBILLABLERESPONSE']._serialized_start=2327
  _globals['_ALLOCSETBILLABLERESPONSE']._serialized_end=2353
  _globals['_ALLOCSETNAMEREQUEST']._serialized_start=2355
  _globals['_ALLOCSETNAMEREQUEST']._serialized_end=2432
  _globals['_ALLOCSETNAMERESPONSE']._serialized_start=2434
  _globals['_ALLOCSETNAMERESPONSE']._serialized_end=2456
  _globals['_ALLOCSETTAGREQUEST']._serialized_start=2458
  _globals['_ALLOCSETTAGREQUEST']._serialized_end=2533
  _globals['_ALLOCSETTAGRESPONSE']._serialized_start=2535
  _globals['_ALLOCSETTAGRESPONSE']._serialized_end=2556
  _globals['_ALLOCGETDEFAULTREQUEST']._serialized_start=2558
  _globals['_ALLOCGETDEFAULTREQUEST']._serialized_end=2582
  _globals['_ALLOCGETDEFAULTRESPONSE']._serialized_start=2584
  _globals['_ALLOCGETDEFAULTRESPONSE']._serialized_end=2651
  _globals['_ALLOCSETDEFAULTREQUEST']._serialized_start=2653
  _globals['_ALLOCSETDEFAULTREQUEST']._serialized_end=2719
  _globals['_ALLOCSETDEFAULTRESPONSE']._serialized_start=2721
  _globals['_ALLOCSETDEFAULTRESPONSE']._serialized_end=2746
  _globals['_FACILITYINTERFACE']._serialized_start=2749
  _globals['_FACILITYINTERFACE']._serialized_end=3168
  _globals['_ALLOCATIONINTERFACE']._serialized_start=3171
  _globals['_ALLOCATIONINTERFACE']._serialized_end=4281
# @@protoc_insertion_point(module_scope)