# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: criterion.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63riterion.proto\x12\tcriterion\"+\n\x1a\x45qualsFloatSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x02\"-\n\x1c\x45qualsIntegerSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x05\"0\n\x1fGreaterThanFloatSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x02\"2\n!GreaterThanIntegerSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x12\"7\n\x1bInRangeFloatSearchCriterion\x12\x0b\n\x03min\x18\x01 \x01(\x02\x12\x0b\n\x03max\x18\x02 \x01(\x02\"9\n\x1dInRangeIntegerSearchCriterion\x12\x0b\n\x03min\x18\x01 \x01(\x12\x12\x0b\n\x03max\x18\x02 \x01(\x12\"-\n\x1cLessThanFloatSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x02\"/\n\x1eLessThanIntegerSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x12\x42?\n#com.imageworks.spcue.grpc.criterionP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'criterion_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.imageworks.spcue.grpc.criterionP\001Z\026opencue_gateway/gen/go'
  _globals['_EQUALSFLOATSEARCHCRITERION']._serialized_start=30
  _globals['_EQUALSFLOATSEARCHCRITERION']._serialized_end=73
  _globals['_EQUALSINTEGERSEARCHCRITERION']._serialized_start=75
  _globals['_EQUALSINTEGERSEARCHCRITERION']._serialized_end=120
  _globals['_GREATERTHANFLOATSEARCHCRITERION']._serialized_start=122
  _globals['_GREATERTHANFLOATSEARCHCRITERION']._serialized_end=170
  _globals['_GREATERTHANINTEGERSEARCHCRITERION']._serialized_start=172
  _globals['_GREATERTHANINTEGERSEARCHCRITERION']._serialized_end=222
  _globals['_INRANGEFLOATSEARCHCRITERION']._serialized_start=224
  _globals['_INRANGEFLOATSEARCHCRITERION']._serialized_end=279
  _globals['_INRANGEINTEGERSEARCHCRITERION']._serialized_start=281
  _globals['_INRANGEINTEGERSEARCHCRITERION']._serialized_end=338
  _globals['_LESSTHANFLOATSEARCHCRITERION']._serialized_start=340
  _globals['_LESSTHANFLOATSEARCHCRITERION']._serialized_end=385
  _globals['_LESSTHANINTEGERSEARCHCRITERION']._serialized_start=387
  _globals['_LESSTHANINTEGERSEARCHCRITERION']._serialized_end=434
# @@protoc_insertion_point(module_scope)