# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: renderPartition.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15renderPartition.proto\x12\x0frenderPartition\"\xb9\x02\n\x0fRenderPartition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03job\x18\x02 \x01(\t\x12\r\n\x05layer\x18\x03 \x01(\t\x12\r\n\x05\x66rame\x18\x04 \x01(\t\x12>\n\x10render_part_type\x18\x05 \x01(\x0e\x32$.renderPartition.RenderPartitionType\x12\x0c\n\x04host\x18\x06 \x01(\t\x12\r\n\x05\x63ores\x18\x07 \x01(\x05\x12\x0e\n\x06memory\x18\x08 \x01(\x03\x12\x11\n\tmax_cores\x18\t \x01(\x05\x12\x12\n\nmax_memory\x18\n \x01(\x03\x12\x16\n\x0emax_gpu_memory\x18\x0b \x01(\x03\x12\x0f\n\x07threads\x18\x0c \x01(\x05\x12\x0c\n\x04gpus\x18\r \x01(\x05\x12\x10\n\x08max_gpus\x18\x0e \x01(\x05\x12\x12\n\ngpu_memory\x18\x0f \x01(\x03\"Q\n\x12RenderPartitionSeq\x12;\n\x11render_partitions\x18\x01 \x03(\x0b\x32 .renderPartition.RenderPartition\"U\n\x17RenderPartDeleteRequest\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\"\x1a\n\x18RenderPartDeleteResponse\"\x9f\x01\n RenderPartSetMaxResourcesRequest\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\x12\r\n\x05\x63ores\x18\x02 \x01(\x05\x12\x0e\n\x06memory\x18\x03 \x01(\x03\x12\x12\n\ngpu_memory\x18\x04 \x01(\x03\x12\x0c\n\x04gpus\x18\x05 \x01(\x05\"#\n!RenderPartSetMaxResourcesResponse*R\n\x13RenderPartitionType\x12\x11\n\rJOB_PARTITION\x10\x00\x12\x13\n\x0fLAYER_PARTITION\x10\x01\x12\x13\n\x0f\x46RAME_PARTITION\x10\x02\x32\xf3\x01\n\x18RenderPartitionInterface\x12]\n\x06\x44\x65lete\x12(.renderPartition.RenderPartDeleteRequest\x1a).renderPartition.RenderPartDeleteResponse\x12x\n\x0fSetMaxResources\x12\x31.renderPartition.RenderPartSetMaxResourcesRequest\x1a\x32.renderPartition.RenderPartSetMaxResourcesResponseBE\n)com.imageworks.spcue.grpc.renderpartitionP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'renderPartition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.imageworks.spcue.grpc.renderpartitionP\001Z\026opencue_gateway/gen/go'
  _globals['_RENDERPARTITIONTYPE']._serialized_start=755
  _globals['_RENDERPARTITIONTYPE']._serialized_end=837
  _globals['_RENDERPARTITION']._serialized_start=43
  _globals['_RENDERPARTITION']._serialized_end=356
  _globals['_RENDERPARTITIONSEQ']._serialized_start=358
  _globals['_RENDERPARTITIONSEQ']._serialized_end=439
  _globals['_RENDERPARTDELETEREQUEST']._serialized_start=441
  _globals['_RENDERPARTDELETEREQUEST']._serialized_end=526
  _globals['_RENDERPARTDELETERESPONSE']._serialized_start=528
  _globals['_RENDERPARTDELETERESPONSE']._serialized_end=554
  _globals['_RENDERPARTSETMAXRESOURCESREQUEST']._serialized_start=557
  _globals['_RENDERPARTSETMAXRESOURCESREQUEST']._serialized_end=716
  _globals['_RENDERPARTSETMAXRESOURCESRESPONSE']._serialized_start=718
  _globals['_RENDERPARTSETMAXRESOURCESRESPONSE']._serialized_end=753
  _globals['_RENDERPARTITIONINTERFACE']._serialized_start=840
  _globals['_RENDERPARTITIONINTERFACE']._serialized_end=1083
# @@protoc_insertion_point(module_scope)