# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: task.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntask.proto\x12\x04task\"w\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04shot\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x04 \x01(\t\x12\x10\n\x08point_id\x18\x05 \x01(\t\x12\x11\n\tmin_cores\x18\x06 \x01(\x02\x12\x14\n\x0c\x61\x64just_cores\x18\x07 \x01(\x02\"$\n\x07TaskSeq\x12\x19\n\x05tasks\x18\x01 \x03(\x0b\x32\n.task.Task\"7\n\x1bTaskClearAdjustmentsRequest\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\"\x1e\n\x1cTaskClearAdjustmentsResponse\"-\n\x11TaskDeleteRequest\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\"\x14\n\x12TaskDeleteResponse\"I\n\x16TaskSetMinCoresRequest\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\x12\x15\n\rnew_min_cores\x18\x02 \x01(\x02\"\x19\n\x17TaskSetMinCoresResponse2\xf3\x01\n\rTaskInterface\x12Y\n\x10\x43learAdjustments\x12!.task.TaskClearAdjustmentsRequest\x1a\".task.TaskClearAdjustmentsResponse\x12;\n\x06\x44\x65lete\x12\x17.task.TaskDeleteRequest\x1a\x18.task.TaskDeleteResponse\x12J\n\x0bSetMinCores\x12\x1c.task.TaskSetMinCoresRequest\x1a\x1d.task.TaskSetMinCoresResponseB:\n\x1e\x63om.imageworks.spcue.grpc.taskP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.imageworks.spcue.grpc.taskP\001Z\026opencue_gateway/gen/go'
  _globals['_TASK']._serialized_start=20
  _globals['_TASK']._serialized_end=139
  _globals['_TASKSEQ']._serialized_start=141
  _globals['_TASKSEQ']._serialized_end=177
  _globals['_TASKCLEARADJUSTMENTSREQUEST']._serialized_start=179
  _globals['_TASKCLEARADJUSTMENTSREQUEST']._serialized_end=234
  _globals['_TASKCLEARADJUSTMENTSRESPONSE']._serialized_start=236
  _globals['_TASKCLEARADJUSTMENTSRESPONSE']._serialized_end=266
  _globals['_TASKDELETEREQUEST']._serialized_start=268
  _globals['_TASKDELETEREQUEST']._serialized_end=313
  _globals['_TASKDELETERESPONSE']._serialized_start=315
  _globals['_TASKDELETERESPONSE']._serialized_end=335
  _globals['_TASKSETMINCORESREQUEST']._serialized_start=337
  _globals['_TASKSETMINCORESREQUEST']._serialized_end=410
  _globals['_TASKSETMINCORESRESPONSE']._serialized_start=412
  _globals['_TASKSETMINCORESRESPONSE']._serialized_end=437
  _globals['_TASKINTERFACE']._serialized_start=440
  _globals['_TASKINTERFACE']._serialized_end=683
# @@protoc_insertion_point(module_scope)