# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: department.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import task_pb2 as task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x65partment.proto\x12\ndepartment\x1a\ntask.proto\"l\n\nDepartment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x03 \x01(\t\x12\x0f\n\x07ti_task\x18\x04 \x01(\t\x12\x11\n\tmin_cores\x18\x05 \x01(\x02\x12\x12\n\nti_managed\x18\x06 \x01(\x08\"<\n\rDepartmentSeq\x12+\n\x0b\x64\x65partments\x18\x01 \x03(\x0b\x32\x16.department.Department\"&\n\x16\x44\x65ptAddDeptNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x19\n\x17\x44\x65ptAddDeptNameResponse\"a\n\x12\x44\x65ptAddTaskRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x0c\n\x04shot\x18\x02 \x01(\t\x12\x11\n\tmin_cores\x18\x03 \x01(\x02\"/\n\x13\x44\x65ptAddTaskResponse\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\"\xa7\x01\n\x13\x44\x65ptAddTasksRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x37\n\x04tmap\x18\x02 \x03(\x0b\x32).department.DeptAddTasksRequest.TmapEntry\x1a+\n\tTmapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"4\n\x14\x44\x65ptAddTasksResponse\x12\x1c\n\x05tasks\x18\x01 \x01(\x0b\x32\r.task.TaskSeq\"C\n\x15\x44\x65ptClearTasksRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\x18\n\x16\x44\x65ptClearTasksResponse\"M\n\x1f\x44\x65ptClearTaskAdjustmentsRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\"\n DeptClearTaskAdjustmentsResponse\"?\n\x11\x44\x65ptDeleteRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\x14\n\x12\x44\x65ptDeleteResponse\"I\n\x1b\x44\x65ptDisableTiManagedRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\x1e\n\x1c\x44\x65ptDisableTiManagedResponse\"p\n\x1a\x44\x65ptEnableTiManagedRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x0f\n\x07ti_task\x18\x02 \x01(\t\x12\x15\n\rmanaged_cores\x18\x03 \x01(\x02\"\x1d\n\x1b\x44\x65ptEnableTiManagedResponse\"\x1f\n\x1d\x44\x65ptGetDepartmentNamesRequest\"/\n\x1e\x44\x65ptGetDepartmentNamesResponse\x12\r\n\x05names\x18\x01 \x03(\t\"A\n\x13\x44\x65ptGetTasksRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"4\n\x14\x44\x65ptGetTasksResponse\x12\x1c\n\x05tasks\x18\x01 \x01(\x0b\x32\r.task.TaskSeq\"/\n\x1f\x44\x65ptRemoveDepartmentNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n DeptRemoveDepartmentNameResponse\"\xad\x01\n\x16\x44\x65ptReplaceTaskRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12:\n\x04tmap\x18\x02 \x03(\x0b\x32,.department.DeptReplaceTaskRequest.TmapEntry\x1a+\n\tTmapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"7\n\x17\x44\x65ptReplaceTaskResponse\x12\x1c\n\x05tasks\x18\x01 \x01(\x0b\x32\r.task.TaskSeq\"_\n\x1a\x44\x65ptSetManagedCoresRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x15\n\rmanaged_cores\x18\x02 \x01(\x02\"\x1d\n\x1b\x44\x65ptSetManagedCoresResponse2\xd5\t\n\x13\x44\x65partmentInterface\x12\\\n\x11\x41\x64\x64\x44\x65partmentName\x12\".department.DeptAddDeptNameRequest\x1a#.department.DeptAddDeptNameResponse\x12J\n\x07\x41\x64\x64Task\x12\x1e.department.DeptAddTaskRequest\x1a\x1f.department.DeptAddTaskResponse\x12M\n\x08\x41\x64\x64Tasks\x12\x1f.department.DeptAddTasksRequest\x1a .department.DeptAddTasksResponse\x12S\n\nClearTasks\x12!.department.DeptClearTasksRequest\x1a\".department.DeptClearTasksResponse\x12q\n\x14\x43learTaskAdjustments\x12+.department.DeptClearTaskAdjustmentsRequest\x1a,.department.DeptClearTaskAdjustmentsResponse\x12G\n\x06\x44\x65lete\x12\x1d.department.DeptDeleteRequest\x1a\x1e.department.DeptDeleteResponse\x12\x65\n\x10\x44isableTiManaged\x12\'.department.DeptDisableTiManagedRequest\x1a(.department.DeptDisableTiManagedResponse\x12\x62\n\x0f\x45nableTiManaged\x12&.department.DeptEnableTiManagedRequest\x1a\'.department.DeptEnableTiManagedResponse\x12k\n\x12GetDepartmentNames\x12).department.DeptGetDepartmentNamesRequest\x1a*.department.DeptGetDepartmentNamesResponse\x12M\n\x08GetTasks\x12\x1f.department.DeptGetTasksRequest\x1a .department.DeptGetTasksResponse\x12q\n\x14RemoveDepartmentName\x12+.department.DeptRemoveDepartmentNameRequest\x1a,.department.DeptRemoveDepartmentNameResponse\x12W\n\x0cReplaceTasks\x12\".department.DeptReplaceTaskRequest\x1a#.department.DeptReplaceTaskResponse\x12\x61\n\x0eSetMangedCores\x12&.department.DeptSetManagedCoresRequest\x1a\'.department.DeptSetManagedCoresResponseB@\n$com.imageworks.spcue.grpc.departmentP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'department_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.imageworks.spcue.grpc.departmentP\001Z\026opencue_gateway/gen/go'
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._options = None
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._serialized_options = b'8\001'
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._options = None
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._serialized_options = b'8\001'
  _globals['_DEPARTMENT']._serialized_start=44
  _globals['_DEPARTMENT']._serialized_end=152
  _globals['_DEPARTMENTSEQ']._serialized_start=154
  _globals['_DEPARTMENTSEQ']._serialized_end=214
  _globals['_DEPTADDDEPTNAMEREQUEST']._serialized_start=216
  _globals['_DEPTADDDEPTNAMEREQUEST']._serialized_end=254
  _globals['_DEPTADDDEPTNAMERESPONSE']._serialized_start=256
  _globals['_DEPTADDDEPTNAMERESPONSE']._serialized_end=281
  _globals['_DEPTADDTASKREQUEST']._serialized_start=283
  _globals['_DEPTADDTASKREQUEST']._serialized_end=380
  _globals['_DEPTADDTASKRESPONSE']._serialized_start=382
  _globals['_DEPTADDTASKRESPONSE']._serialized_end=429
  _globals['_DEPTADDTASKSREQUEST']._serialized_start=432
  _globals['_DEPTADDTASKSREQUEST']._serialized_end=599
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._serialized_start=556
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._serialized_end=599
  _globals['_DEPTADDTASKSRESPONSE']._serialized_start=601
  _globals['_DEPTADDTASKSRESPONSE']._serialized_end=653
  _globals['_DEPTCLEARTASKSREQUEST']._serialized_start=655
  _globals['_DEPTCLEARTASKSREQUEST']._serialized_end=722
  _globals['_DEPTCLEARTASKSRESPONSE']._serialized_start=724
  _globals['_DEPTCLEARTASKSRESPONSE']._serialized_end=748
  _globals['_DEPTCLEARTASKADJUSTMENTSREQUEST']._serialized_start=750
  _globals['_DEPTCLEARTASKADJUSTMENTSREQUEST']._serialized_end=827
  _globals['_DEPTCLEARTASKADJUSTMENTSRESPONSE']._serialized_start=829
  _globals['_DEPTCLEARTASKADJUSTMENTSRESPONSE']._serialized_end=863
  _globals['_DEPTDELETEREQUEST']._serialized_start=865
  _globals['_DEPTDELETEREQUEST']._serialized_end=928
  _globals['_DEPTDELETERESPONSE']._serialized_start=930
  _globals['_DEPTDELETERESPONSE']._serialized_end=950
  _globals['_DEPTDISABLETIMANAGEDREQUEST']._serialized_start=952
  _globals['_DEPTDISABLETIMANAGEDREQUEST']._serialized_end=1025
  _globals['_DEPTDISABLETIMANAGEDRESPONSE']._serialized_start=1027
  _globals['_DEPTDISABLETIMANAGEDRESPONSE']._serialized_end=1057
  _globals['_DEPTENABLETIMANAGEDREQUEST']._serialized_start=1059
  _globals['_DEPTENABLETIMANAGEDREQUEST']._serialized_end=1171
  _globals['_DEPTENABLETIMANAGEDRESPONSE']._serialized_start=1173
  _globals['_DEPTENABLETIMANAGEDRESPONSE']._serialized_end=1202
  _globals['_DEPTGETDEPARTMENTNAMESREQUEST']._serialized_start=1204
  _globals['_DEPTGETDEPARTMENTNAMESREQUEST']._serialized_end=1235
  _globals['_DEPTGETDEPARTMENTNAMESRESPONSE']._serialized_start=1237
  _globals['_DEPTGETDEPARTMENTNAMESRESPONSE']._serialized_end=1284
  _globals['_DEPTGETTASKSREQUEST']._serialized_start=1286
  _globals['_DEPTGETTASKSREQUEST']._serialized_end=1351
  _globals['_DEPTGETTASKSRESPONSE']._serialized_start=1353
  _globals['_DEPTGETTASKSRESPONSE']._serialized_end=1405
  _globals['_DEPTREMOVEDEPARTMENTNAMEREQUEST']._serialized_start=1407
  _globals['_DEPTREMOVEDEPARTMENTNAMEREQUEST']._serialized_end=1454
  _globals['_DEPTREMOVEDEPARTMENTNAMERESPONSE']._serialized_start=1456
  _globals['_DEPTREMOVEDEPARTMENTNAMERESPONSE']._serialized_end=1490
  _globals['_DEPTREPLACETASKREQUEST']._serialized_start=1493
  _globals['_DEPTREPLACETASKREQUEST']._serialized_end=1666
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._serialized_start=556
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._serialized_end=599
  _globals['_DEPTREPLACETASKRESPONSE']._serialized_start=1668
  _globals['_DEPTREPLACETASKRESPONSE']._serialized_end=1723
  _globals['_DEPTSETMANAGEDCORESREQUEST']._serialized_start=1725
  _globals['_DEPTSETMANAGEDCORESREQUEST']._serialized_end=1820
  _globals['_DEPTSETMANAGEDCORESRESPONSE']._serialized_start=1822
  _globals['_DEPTSETMANAGEDCORESRESPONSE']._serialized_end=1851
  _globals['_DEPARTMENTINTERFACE']._serialized_start=1854
  _globals['_DEPARTMENTINTERFACE']._serialized_end=3091
# @@protoc_insertion_point(module_scope)