# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: filter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import job_pb2 as job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66ilter.proto\x12\x06\x66ilter\x1a\tjob.proto\"\xd1\x01\n\x06\x41\x63tion\x12\n\n\x02id\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.filter.ActionType\x12+\n\nvalue_type\x18\x03 \x01(\x0e\x32\x17.filter.ActionValueType\x12\x13\n\x0bgroup_value\x18\x04 \x01(\t\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\x12\x15\n\rinteger_value\x18\x06 \x01(\x05\x12\x13\n\x0b\x66loat_value\x18\x07 \x01(\x02\x12\x15\n\rboolean_value\x18\x08 \x01(\x08\",\n\tActionSeq\x12\x1f\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x0e.filter.Action\"d\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.filter.FilterType\x12\r\n\x05order\x18\x04 \x01(\x02\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\",\n\tFilterSeq\x12\x1f\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x0e.filter.Filter\"l\n\x07Matcher\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\x07subject\x18\x02 \x01(\x0e\x32\x14.filter.MatchSubject\x12\x1f\n\x04type\x18\x03 \x01(\x0e\x32\x11.filter.MatchType\x12\r\n\x05input\x18\x04 \x01(\t\"/\n\nMatcherSeq\x12!\n\x08matchers\x18\x01 \x03(\x0b\x32\x0f.filter.Matcher\"5\n\x13\x41\x63tionCommitRequest\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"\x16\n\x14\x41\x63tionCommitResponse\"5\n\x13\x41\x63tionDeleteRequest\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"\x16\n\x14\x41\x63tionDeleteResponse\">\n\x1c\x41\x63tionGetParentFilterRequest\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"?\n\x1d\x41\x63tionGetParentFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"Y\n\x19\x46ilterCreateActionRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x1c\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x0e.filter.Action\"<\n\x1a\x46ilterCreateActionResponse\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"[\n\x1a\x46ilterCreateMatcherRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x1d\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x0f.filter.Matcher\"?\n\x1b\x46ilterCreateMatcherResponse\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"5\n\x13\x46ilterDeleteRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x16\n\x14\x46ilterDeleteResponse\"5\n\x17\x46ilterFindFilterRequest\x12\x0c\n\x04show\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x18\x46ilterFindFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"9\n\x17\x46ilterGetActionsRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\">\n\x18\x46ilterGetActionsResponse\x12\"\n\x07\x61\x63tions\x18\x01 \x01(\x0b\x32\x11.filter.ActionSeq\":\n\x18\x46ilterGetMatchersRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"A\n\x19\x46ilterGetMatchersResponse\x12$\n\x08matchers\x18\x01 \x01(\x0b\x32\x12.filter.MatcherSeq\"9\n\x17\x46ilterLowerOrderRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x1a\n\x18\x46ilterLowerOrderResponse\"9\n\x17\x46ilterOrderFirstRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x1a\n\x18\x46ilterOrderFirstResponse\"8\n\x16\x46ilterOrderLastRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x19\n\x17\x46ilterOrderLastResponse\"9\n\x17\x46ilterRaiseOrderRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x1a\n\x18\x46ilterRaiseOrderResponse\"Z\n\x1d\x46ilterRunFilterOnGroupRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x19\n\x05group\x18\x02 \x01(\x0b\x32\n.job.Group\" \n\x1e\x46ilterRunFilterOnGroupResponse\"Y\n\x1c\x46ilterRunFilterOnJobsRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x19\n\x04jobs\x18\x02 \x01(\x0b\x32\x0b.job.JobSeq\"\x1f\n\x1d\x46ilterRunFilterOnJobsResponse\"J\n\x17\x46ilterSetEnabledRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x1a\n\x18\x46ilterSetEnabledResponse\"D\n\x14\x46ilterSetNameRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x46ilterSetNameResponse\"F\n\x15\x46ilterSetOrderRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\r\n\x05order\x18\x02 \x01(\x05\"\x18\n\x16\x46ilterSetOrderResponse\"X\n\x14\x46ilterSetTypeRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.filter.FilterType\"\x17\n\x15\x46ilterSetTypeResponse\"8\n\x14MatcherCommitRequest\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"\x17\n\x15MatcherCommitResponse\"8\n\x14MatcherDeleteRequest\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"\x17\n\x15MatcherDeleteResponse\"A\n\x1dMatcherGetParentFilterRequest\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"@\n\x1eMatcherGetParentFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter*\xd1\x02\n\nActionType\x12\x15\n\x11MOVE_JOB_TO_GROUP\x10\x00\x12\r\n\tPAUSE_JOB\x10\x01\x12\x15\n\x11SET_JOB_MIN_CORES\x10\x02\x12\x15\n\x11SET_JOB_MAX_CORES\x10\x03\x12\x13\n\x0fSTOP_PROCESSING\x10\x04\x12\x14\n\x10SET_JOB_PRIORITY\x10\x05\x12\x1d\n\x19SET_ALL_RENDER_LAYER_TAGS\x10\x06\x12\x1f\n\x1bSET_ALL_RENDER_LAYER_MEMORY\x10\x07\x12\"\n\x1aSET_ALL_RENDER_LAYER_CORES\x10\x08\x1a\x02\x08\x01\x12\x18\n\x14SET_MEMORY_OPTIMIZER\x10\t\x12\"\n\x1eSET_ALL_RENDER_LAYER_MIN_CORES\x10\n\x12\"\n\x1eSET_ALL_RENDER_LAYER_MAX_CORES\x10\x0b*u\n\x0f\x41\x63tionValueType\x12\x0e\n\nGROUP_TYPE\x10\x00\x12\x0f\n\x0bSTRING_TYPE\x10\x01\x12\x10\n\x0cINTEGER_TYPE\x10\x02\x12\x0e\n\nFLOAT_TYPE\x10\x03\x12\x10\n\x0c\x42OOLEAN_TYPE\x10\x04\x12\r\n\tNONE_TYPE\x10\x05**\n\nFilterType\x12\r\n\tMATCH_ANY\x10\x00\x12\r\n\tMATCH_ALL\x10\x01*x\n\x0cMatchSubject\x12\x0c\n\x08JOB_NAME\x10\x00\x12\x08\n\x04SHOW\x10\x01\x12\x08\n\x04SHOT\x10\x02\x12\x08\n\x04USER\x10\x03\x12\x10\n\x0cSERVICE_NAME\x10\x04\x12\x0c\n\x08PRIORITY\x10\x05\x12\x0c\n\x08\x46\x41\x43ILITY\x10\x06\x12\x0e\n\nLAYER_NAME\x10\x07*n\n\tMatchType\x12\x0c\n\x08\x43ONTAINS\x10\x00\x12\x14\n\x10\x44OES_NOT_CONTAIN\x10\x01\x12\x06\n\x02IS\x10\x02\x12\n\n\x06IS_NOT\x10\x03\x12\t\n\x05REGEX\x10\x04\x12\x0f\n\x0b\x42\x45GINS_WITH\x10\x05\x12\r\n\tENDS_WITH\x10\x06\x32\xfb\x01\n\x0f\x41\x63tionInterface\x12\x43\n\x06\x43ommit\x12\x1b.filter.ActionCommitRequest\x1a\x1c.filter.ActionCommitResponse\x12\x43\n\x06\x44\x65lete\x12\x1b.filter.ActionDeleteRequest\x1a\x1c.filter.ActionDeleteResponse\x12^\n\x0fGetParentFilter\x12$.filter.ActionGetParentFilterRequest\x1a%.filter.ActionGetParentFilterResponse2\xad\n\n\x0f\x46ilterInterface\x12U\n\x0c\x43reateAction\x12!.filter.FilterCreateActionRequest\x1a\".filter.FilterCreateActionResponse\x12X\n\rCreateMatcher\x12\".filter.FilterCreateMatcherRequest\x1a#.filter.FilterCreateMatcherResponse\x12\x43\n\x06\x44\x65lete\x12\x1b.filter.FilterDeleteRequest\x1a\x1c.filter.FilterDeleteResponse\x12O\n\nFindFilter\x12\x1f.filter.FilterFindFilterRequest\x1a .filter.FilterFindFilterResponse\x12O\n\nGetActions\x12\x1f.filter.FilterGetActionsRequest\x1a .filter.FilterGetActionsResponse\x12R\n\x0bGetMatchers\x12 .filter.FilterGetMatchersRequest\x1a!.filter.FilterGetMatchersResponse\x12O\n\nLowerOrder\x12\x1f.filter.FilterLowerOrderRequest\x1a .filter.FilterLowerOrderResponse\x12O\n\nOrderFirst\x12\x1f.filter.FilterOrderFirstRequest\x1a .filter.FilterOrderFirstResponse\x12L\n\tOrderLast\x12\x1e.filter.FilterOrderLastRequest\x1a\x1f.filter.FilterOrderLastResponse\x12O\n\nRaiseOrder\x12\x1f.filter.FilterRaiseOrderRequest\x1a .filter.FilterRaiseOrderResponse\x12\x61\n\x10RunFilterOnGroup\x12%.filter.FilterRunFilterOnGroupRequest\x1a&.filter.FilterRunFilterOnGroupResponse\x12^\n\x0fRunFilterOnJobs\x12$.filter.FilterRunFilterOnJobsRequest\x1a%.filter.FilterRunFilterOnJobsResponse\x12O\n\nSetEnabled\x12\x1f.filter.FilterSetEnabledRequest\x1a .filter.FilterSetEnabledResponse\x12\x46\n\x07SetName\x12\x1c.filter.FilterSetNameRequest\x1a\x1d.filter.FilterSetNameResponse\x12I\n\x08SetOrder\x12\x1d.filter.FilterSetOrderRequest\x1a\x1e.filter.FilterSetOrderResponse\x12\x46\n\x07SetType\x12\x1c.filter.FilterSetTypeRequest\x1a\x1d.filter.FilterSetTypeResponse2\x82\x02\n\x10MatcherInterface\x12\x45\n\x06\x43ommit\x12\x1c.filter.MatcherCommitRequest\x1a\x1d.filter.MatcherCommitResponse\x12\x45\n\x06\x44\x65lete\x12\x1c.filter.MatcherDeleteRequest\x1a\x1d.filter.MatcherDeleteResponse\x12`\n\x0fGetParentFilter\x12%.filter.MatcherGetParentFilterRequest\x1a&.filter.MatcherGetParentFilterResponseB<\n com.imageworks.spcue.grpc.filterP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.imageworks.spcue.grpc.filterP\001Z\026opencue_gateway/gen/go'
  _globals['_ACTIONTYPE'].values_by_name["SET_ALL_RENDER_LAYER_CORES"]._options = None
  _globals['_ACTIONTYPE'].values_by_name["SET_ALL_RENDER_LAYER_CORES"]._serialized_options = b'\010\001'
  _globals['_ACTIONTYPE']._serialized_start=2950
  _globals['_ACTIONTYPE']._serialized_end=3287
  _globals['_ACTIONVALUETYPE']._serialized_start=3289
  _globals['_ACTIONVALUETYPE']._serialized_end=3406
  _globals['_FILTERTYPE']._serialized_start=3408
  _globals['_FILTERTYPE']._serialized_end=3450
  _globals['_MATCHSUBJECT']._serialized_start=3452
  _globals['_MATCHSUBJECT']._serialized_end=3572
  _globals['_MATCHTYPE']._serialized_start=3574
  _globals['_MATCHTYPE']._serialized_end=3684
  _globals['_ACTION']._serialized_start=36
  _globals['_ACTION']._serialized_end=245
  _globals['_ACTIONSEQ']._serialized_start=247
  _globals['_ACTIONSEQ']._serialized_end=291
  _globals['_FILTER']._serialized_start=293
  _globals['_FILTER']._serialized_end=393
  _globals['_FILTERSEQ']._serialized_start=395
  _globals['_FILTERSEQ']._serialized_end=439
  _globals['_MATCHER']._serialized_start=441
  _globals['_MATCHER']._serialized_end=549
  _globals['_MATCHERSEQ']._serialized_start=551
  _globals['_MATCHERSEQ']._serialized_end=598
  _globals['_ACTIONCOMMITREQUEST']._serialized_start=600
  _globals['_ACTIONCOMMITREQUEST']._serialized_end=653
  _globals['_ACTIONCOMMITRESPONSE']._serialized_start=655
  _globals['_ACTIONCOMMITRESPONSE']._serialized_end=677
  _globals['_ACTIONDELETEREQUEST']._serialized_start=679
  _globals['_ACTIONDELETEREQUEST']._serialized_end=732
  _globals['_ACTIONDELETERESPONSE']._serialized_start=734
  _globals['_ACTIONDELETERESPONSE']._serialized_end=756
  _globals['_ACTIONGETPARENTFILTERREQUEST']._serialized_start=758
  _globals['_ACTIONGETPARENTFILTERREQUEST']._serialized_end=820
  _globals['_ACTIONGETPARENTFILTERRESPONSE']._serialized_start=822
  _globals['_ACTIONGETPARENTFILTERRESPONSE']._serialized_end=885
  _globals['_FILTERCREATEACTIONREQUEST']._serialized_start=887
  _globals['_FILTERCREATEACTIONREQUEST']._serialized_end=976
  _globals['_FILTERCREATEACTIONRESPONSE']._serialized_start=978
  _globals['_FILTERCREATEACTIONRESPONSE']._serialized_end=1038
  _globals['_FILTERCREATEMATCHERREQUEST']._serialized_start=1040
  _globals['_FILTERCREATEMATCHERREQUEST']._serialized_end=1131
  _globals['_FILTERCREATEMATCHERRESPONSE']._serialized_start=1133
  _globals['_FILTERCREATEMATCHERRESPONSE']._serialized_end=1196
  _globals['_FILTERDELETEREQUEST']._serialized_start=1198
  _globals['_FILTERDELETEREQUEST']._serialized_end=1251
  _globals['_FILTERDELETERESPONSE']._serialized_start=1253
  _globals['_FILTERDELETERESPONSE']._serialized_end=1275
  _globals['_FILTERFINDFILTERREQUEST']._serialized_start=1277
  _globals['_FILTERFINDFILTERREQUEST']._serialized_end=1330
  _globals['_FILTERFINDFILTERRESPONSE']._serialized_start=1332
  _globals['_FILTERFINDFILTERRESPONSE']._serialized_end=1390
  _globals['_FILTERGETACTIONSREQUEST']._serialized_start=1392
  _globals['_FILTERGETACTIONSREQUEST']._serialized_end=1449
  _globals['_FILTERGETACTIONSRESPONSE']._serialized_start=1451
  _globals['_FILTERGETACTIONSRESPONSE']._serialized_end=1513
  _globals['_FILTERGETMATCHERSREQUEST']._serialized_start=1515
  _globals['_FILTERGETMATCHERSREQUEST']._serialized_end=1573
  _globals['_FILTERGETMATCHERSRESPONSE']._serialized_start=1575
  _globals['_FILTERGETMATCHERSRESPONSE']._serialized_end=1640
  _globals['_FILTERLOWERORDERREQUEST']._serialized_start=1642
  _globals['_FILTERLOWERORDERREQUEST']._serialized_end=1699
  _globals['_FILTERLOWERORDERRESPONSE']._serialized_start=1701
  _globals['_FILTERLOWERORDERRESPONSE']._serialized_end=1727
  _globals['_FILTERORDERFIRSTREQUEST']._serialized_start=1729
  _globals['_FILTERORDERFIRSTREQUEST']._serialized_end=1786
  _globals['_FILTERORDERFIRSTRESPONSE']._serialized_start=1788
  _globals['_FILTERORDERFIRSTRESPONSE']._serialized_end=1814
  _globals['_FILTERORDERLASTREQUEST']._serialized_start=1816
  _globals['_FILTERORDERLASTREQUEST']._serialized_end=1872
  _globals['_FILTERORDERLASTRESPONSE']._serialized_start=1874
  _globals['_FILTERORDERLASTRESPONSE']._serialized_end=1899
  _globals['_FILTERRAISEORDERREQUEST']._serialized_start=1901
  _globals['_FILTERRAISEORDERREQUEST']._serialized_end=1958
  _globals['_FILTERRAISEORDERRESPONSE']._serialized_start=1960
  _globals['_FILTERRAISEORDERRESPONSE']._serialized_end=1986
  _globals['_FILTERRUNFILTERONGROUPREQUEST']._serialized_start=1988
  _globals['_FILTERRUNFILTERONGROUPREQUEST']._serialized_end=2078
  _globals['_FILTERRUNFILTERONGROUPRESPONSE']._serialized_start=2080
  _globals['_FILTERRUNFILTERONGROUPRESPONSE']._serialized_end=2112
  _globals['_FILTERRUNFILTERONJOBSREQUEST']._serialized_start=2114
  _globals['_FILTERRUNFILTERONJOBSREQUEST']._serialized_end=2203
  _globals['_FILTERRUNFILTERONJOBSRESPONSE']._serialized_start=2205
  _globals['_FILTERRUNFILTERONJOBSRESPONSE']._serialized_end=2236
  _globals['_FILTERSETENABLEDREQUEST']._serialized_start=2238
  _globals['_FILTERSETENABLEDREQUEST']._serialized_end=2312
  _globals['_FILTERSETENABLEDRESPONSE']._serialized_start=2314
  _globals['_FILTERSETENABLEDRESPONSE']._serialized_end=2340
  _globals['_FILTERSETNAMEREQUEST']._serialized_start=2342
  _globals['_FILTERSETNAMEREQUEST']._serialized_end=2410
  _globals['_FILTERSETNAMERESPONSE']._serialized_start=2412
  _globals['_FILTERSETNAMERESPONSE']._serialized_end=2435
  _globals['_FILTERSETORDERREQUEST']._serialized_start=2437
  _globals['_FILTERSETORDERREQUEST']._serialized_end=2507
  _globals['_FILTERSETORDERRESPONSE']._serialized_start=2509
  _globals['_FILTERSETORDERRESPONSE']._serialized_end=2533
  _globals['_FILTERSETTYPEREQUEST']._serialized_start=2535
  _globals['_FILTERSETTYPEREQUEST']._serialized_end=2623
  _globals['_FILTERSETTYPERESPONSE']._serialized_start=2625
  _globals['_FILTERSETTYPERESPONSE']._serialized_end=2648
  _globals['_MATCHERCOMMITREQUEST']._serialized_start=2650
  _globals['_MATCHERCOMMITREQUEST']._serialized_end=2706
  _globals['_MATCHERCOMMITRESPONSE']._serialized_start=2708
  _globals['_MATCHERCOMMITRESPONSE']._serialized_end=2731
  _globals['_MATCHERDELETEREQUEST']._serialized_start=2733
  _globals['_MATCHERDELETEREQUEST']._serialized_end=2789
  _globals['_MATCHERDELETERESPONSE']._serialized_start=2791
  _globals['_MATCHERDELETERESPONSE']._serialized_end=2814
  _globals['_MATCHERGETPARENTFILTERREQUEST']._serialized_start=2816
  _globals['_MATCHERGETPARENTFILTERREQUEST']._serialized_end=2881
  _globals['_MATCHERGETPARENTFILTERRESPONSE']._serialized_start=2883
  _globals['_MATCHERGETPARENTFILTERRESPONSE']._serialized_end=2947
  _globals['_ACTIONINTERFACE']._serialized_start=3687
  _globals['_ACTIONINTERFACE']._serialized_end=3938
  _globals['_FILTERINTERFACE']._serialized_start=3941
  _globals['_FILTERINTERFACE']._serialized_end=5266
  _globals['_MATCHERINTERFACE']._serialized_start=5269
  _globals['_MATCHERINTERFACE']._serialized_end=5527
# @@protoc_insertion_point(module_scope)