# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x07service\"\xfe\x01\n\x07Service\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nthreadable\x18\x03 \x01(\x08\x12\x11\n\tmin_cores\x18\x04 \x01(\x05\x12\x11\n\tmax_cores\x18\x05 \x01(\x05\x12\x12\n\nmin_memory\x18\x06 \x01(\x03\x12\x16\n\x0emin_gpu_memory\x18\x07 \x01(\x03\x12\x0c\n\x04tags\x18\x08 \x03(\t\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\x13\n\x0btimeout_llu\x18\n \x01(\x05\x12\x10\n\x08min_gpus\x18\x0b \x01(\x05\x12\x10\n\x08max_gpus\x18\x0c \x01(\x05\x12\x1b\n\x13min_memory_increase\x18\r \x01(\x05\"0\n\nServiceSeq\x12\"\n\x08services\x18\x01 \x03(\x0b\x32\x10.service.Service\"=\n\x0fServiceOverride\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1e\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x10.service.Service\"I\n\x12ServiceOverrideSeq\x12\x33\n\x11service_overrides\x18\x01 \x03(\x0b\x32\x18.service.ServiceOverride\"=\n\x1bServiceCreateServiceRequest\x12\x1e\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x10.service.Service\"A\n\x1cServiceCreateServiceResponse\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"9\n\x14ServiceDeleteRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x17\n\x15ServiceDeleteResponse\"\"\n ServiceGetDefaultServicesRequest\"J\n!ServiceGetDefaultServicesResponse\x12%\n\x08services\x18\x01 \x01(\x0b\x32\x13.service.ServiceSeq\"(\n\x18ServiceGetServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\">\n\x19ServiceGetServiceResponse\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"9\n\x14ServiceUpdateRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x17\n\x15ServiceUpdateResponse\"A\n\x1cServiceOverrideDeleteRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x1f\n\x1dServiceOverrideDeleteResponse\"A\n\x1cServiceOverrideUpdateRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x1f\n\x1dServiceOverrideUpdateResponse2\xc4\x03\n\x10ServiceInterface\x12\\\n\rCreateService\x12$.service.ServiceCreateServiceRequest\x1a%.service.ServiceCreateServiceResponse\x12G\n\x06\x44\x65lete\x12\x1d.service.ServiceDeleteRequest\x1a\x1e.service.ServiceDeleteResponse\x12k\n\x12GetDefaultServices\x12).service.ServiceGetDefaultServicesRequest\x1a*.service.ServiceGetDefaultServicesResponse\x12S\n\nGetService\x12!.service.ServiceGetServiceRequest\x1a\".service.ServiceGetServiceResponse\x12G\n\x06Update\x12\x1d.service.ServiceUpdateRequest\x1a\x1e.service.ServiceUpdateResponse2\xcc\x01\n\x18ServiceOverrideInterface\x12W\n\x06\x44\x65lete\x12%.service.ServiceOverrideDeleteRequest\x1a&.service.ServiceOverrideDeleteResponse\x12W\n\x06Update\x12%.service.ServiceOverrideUpdateRequest\x1a&.service.ServiceOverrideUpdateResponseB=\n!com.imageworks.spcue.grpc.serviceP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.imageworks.spcue.grpc.serviceP\001Z\026opencue_gateway/gen/go'
  _globals['_SERVICE']._serialized_start=27
  _globals['_SERVICE']._serialized_end=281
  _globals['_SERVICESEQ']._serialized_start=283
  _globals['_SERVICESEQ']._serialized_end=331
  _globals['_SERVICEOVERRIDE']._serialized_start=333
  _globals['_SERVICEOVERRIDE']._serialized_end=394
  _globals['_SERVICEOVERRIDESEQ']._serialized_start=396
  _globals['_SERVICEOVERRIDESEQ']._serialized_end=469
  _globals['_SERVICECREATESERVICEREQUEST']._serialized_start=471
  _globals['_SERVICECREATESERVICEREQUEST']._serialized_end=532
  _globals['_SERVICECREATESERVICERESPONSE']._serialized_start=534
  _globals['_SERVICECREATESERVICERESPONSE']._serialized_end=599
  _globals['_SERVICEDELETEREQUEST']._serialized_start=601
  _globals['_SERVICEDELETEREQUEST']._serialized_end=658
  _globals['_SERVICEDELETERESPONSE']._serialized_start=660
  _globals['_SERVICEDELETERESPONSE']._serialized_end=683
  _globals['_SERVICEGETDEFAULTSERVICESREQUEST']._serialized_start=685
  _globals['_SERVICEGETDEFAULTSERVICESREQUEST']._serialized_end=719
  _globals['_SERVICEGETDEFAULTSERVICESRESPONSE']._serialized_start=721
  _globals['_SERVICEGETDEFAULTSERVICESRESPONSE']._serialized_end=795
  _globals['_SERVICEGETSERVICEREQUEST']._serialized_start=797
  _globals['_SERVICEGETSERVICEREQUEST']._serialized_end=837
  _globals['_SERVICEGETSERVICERESPONSE']._serialized_start=839
  _globals['_SERVICEGETSERVICERESPONSE']._serialized_end=901
  _globals['_SERVICEUPDATEREQUEST']._serialized_start=903
  _globals['_SERVICEUPDATEREQUEST']._serialized_end=960
  _globals['_SERVICEUPDATERESPONSE']._serialized_start=962
  _globals['_SERVICEUPDATERESPONSE']._serialized_end=985
  _globals['_SERVICEOVERRIDEDELETEREQUEST']._serialized_start=987
  _globals['_SERVICEOVERRIDEDELETEREQUEST']._serialized_end=1052
  _globals['_SERVICEOVERRIDEDELETERESPONSE']._serialized_start=1054
  _globals['_SERVICEOVERRIDEDELETERESPONSE']._serialized_end=1085
  _globals['_SERVICEOVERRIDEUPDATEREQUEST']._serialized_start=1087
  _globals['_SERVICEOVERRIDEUPDATEREQUEST']._serialized_end=1152
  _globals['_SERVICEOVERRIDEUPDATERESPONSE']._serialized_start=1154
  _globals['_SERVICEOVERRIDEUPDATERESPONSE']._serialized_end=1185
  _globals['_SERVICEINTERFACE']._serialized_start=1188
  _globals['_SERVICEINTERFACE']._serialized_end=1640
  _globals['_SERVICEOVERRIDEINTERFACE']._serialized_start=1643
  _globals['_SERVICEOVERRIDEINTERFACE']._serialized_end=1847
# @@protoc_insertion_point(module_scope)